pub struct DecodablePayloads { /* private fields */ }Expand description
A codec-decoded set of payloads that can be deserialized later with to a user provided type.
Implementations
Sourceimpl DecodablePayloads
impl DecodablePayloads
Sourcepub fn new(
payloads: Vec<Payload>,
payload_converter: PayloadConverter,
context: SerializationContextData,
) -> DecodablePayloads
pub fn new( payloads: Vec<Payload>, payload_converter: PayloadConverter, context: SerializationContextData, ) -> DecodablePayloads
Create a new decodable payload set from raw payloads and the converter context needed to deserialize them later.
Sourcepub fn deserialize<T>(&self) -> Result<T, PayloadConversionError>where
T: TemporalDeserializable + 'static,
pub fn deserialize<T>(&self) -> Result<T, PayloadConversionError>where
T: TemporalDeserializable + 'static,
Deserialize these payloads into a typed value using the stored payload converter.