pub struct MultiArgs6<A, B, C, D, E, F>(pub A, pub B, pub C, pub D, pub E, pub F);Expand description
Wrapper for 6 typed arguments, enabling multi-arg serialization.
Tuple Fields
0: A1: B2: C3: D4: E5: FTrait Implementations
Sourceimpl<A: Clone, B: Clone, C: Clone, D: Clone, E: Clone, F: Clone> Clone for MultiArgs6<A, B, C, D, E, F>
impl<A: Clone, B: Clone, C: Clone, D: Clone, E: Clone, F: Clone> Clone for MultiArgs6<A, B, C, D, E, F>
Sourcefn clone(&self) -> MultiArgs6<A, B, C, D, E, F>
fn clone(&self) -> MultiArgs6<A, B, C, D, E, F>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A: Debug, B: Debug, C: Debug, D: Debug, E: Debug, F: Debug> Debug for MultiArgs6<A, B, C, D, E, F>
impl<A: Debug, B: Debug, C: Debug, D: Debug, E: Debug, F: Debug> Debug for MultiArgs6<A, B, C, D, E, F>
Sourceimpl<A, B, C, D, E, F> From<(A, B, C, D, E, F)> for MultiArgs6<A, B, C, D, E, F>
impl<A, B, C, D, E, F> From<(A, B, C, D, E, F)> for MultiArgs6<A, B, C, D, E, F>
Sourcefn from(t: (A, B, C, D, E, F)) -> Self
fn from(t: (A, B, C, D, E, F)) -> Self
Converts to this type from the input type.
Sourceimpl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq> PartialEq for MultiArgs6<A, B, C, D, E, F>
impl<A: PartialEq, B: PartialEq, C: PartialEq, D: PartialEq, E: PartialEq, F: PartialEq> PartialEq for MultiArgs6<A, B, C, D, E, F>
Sourcefn eq(&self, other: &MultiArgs6<A, B, C, D, E, F>) -> bool
fn eq(&self, other: &MultiArgs6<A, B, C, D, E, F>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<A, B, C, D, E, F> TemporalDeserializable for MultiArgs6<A, B, C, D, E, F>where
A: TemporalDeserializable + 'static,
B: TemporalDeserializable + 'static,
C: TemporalDeserializable + 'static,
D: TemporalDeserializable + 'static,
E: TemporalDeserializable + 'static,
F: TemporalDeserializable + 'static,
impl<A, B, C, D, E, F> TemporalDeserializable for MultiArgs6<A, B, C, D, E, F>where
A: TemporalDeserializable + 'static,
B: TemporalDeserializable + 'static,
C: TemporalDeserializable + 'static,
D: TemporalDeserializable + 'static,
E: TemporalDeserializable + 'static,
F: TemporalDeserializable + 'static,
Sourcefn from_payload(
_: &SerializationContext<'_>,
_: Payload,
) -> Result<Self, PayloadConversionError>
fn from_payload( _: &SerializationContext<'_>, _: Payload, ) -> Result<Self, PayloadConversionError>
Deserialize from a single
Payload.Sourcefn from_payloads(
ctx: &SerializationContext<'_>,
payloads: Vec<Payload>,
) -> Result<Self, PayloadConversionError>
fn from_payloads( ctx: &SerializationContext<'_>, payloads: Vec<Payload>, ) -> Result<Self, PayloadConversionError>
Convert from multiple payloads. Override this for types representing multiple arguments.
Sourcefn from_serde(
_: &dyn ErasedSerdePayloadConverter,
_ctx: &SerializationContext<'_>,
_: Payload,
) -> Result<Self, PayloadConversionError>
fn from_serde( _: &dyn ErasedSerdePayloadConverter, _ctx: &SerializationContext<'_>, _: Payload, ) -> Result<Self, PayloadConversionError>
Deserialize from a serde-based payload converter.
Sourceimpl<A, B, C, D, E, F> TemporalSerializable for MultiArgs6<A, B, C, D, E, F>where
A: TemporalSerializable + 'static,
B: TemporalSerializable + 'static,
C: TemporalSerializable + 'static,
D: TemporalSerializable + 'static,
E: TemporalSerializable + 'static,
F: TemporalSerializable + 'static,
impl<A, B, C, D, E, F> TemporalSerializable for MultiArgs6<A, B, C, D, E, F>where
A: TemporalSerializable + 'static,
B: TemporalSerializable + 'static,
C: TemporalSerializable + 'static,
D: TemporalSerializable + 'static,
E: TemporalSerializable + 'static,
F: TemporalSerializable + 'static,
Sourcefn to_payload(
&self,
_: &SerializationContext<'_>,
) -> Result<Payload, PayloadConversionError>
fn to_payload( &self, _: &SerializationContext<'_>, ) -> Result<Payload, PayloadConversionError>
Convert this value into a single
Payload.Sourcefn to_payloads(
&self,
ctx: &SerializationContext<'_>,
) -> Result<Vec<Payload>, PayloadConversionError>
fn to_payloads( &self, ctx: &SerializationContext<'_>, ) -> Result<Vec<Payload>, PayloadConversionError>
Convert to multiple payloads. Override this for types representing multiple arguments.
impl<A: Eq, B: Eq, C: Eq, D: Eq, E: Eq, F: Eq> Eq for MultiArgs6<A, B, C, D, E, F>
impl<A, B, C, D, E, F> StructuralPartialEq for MultiArgs6<A, B, C, D, E, F>