ActivityCloseTimeouts

Enum ActivityCloseTimeouts 

pub enum ActivityCloseTimeouts {
    ScheduleToClose(Duration),
    StartToClose(Duration),
    Both {
        schedule_to_close: Duration,
        start_to_close: Duration,
    },
}
Represents Activity schedule-to-close and start-to-close timeouts for the purposes of specifying Activity options. Specifying at least one of them is required, but specifying both is also allowed. Note that this type does not cover all available timeout options for an Activity.

Variants



ScheduleToClose(Duration)

Total time the Activity is allowed to run, including retries.



StartToClose(Duration)

Maximum time of a single Activity execution attempt. Note that the Temporal Server doesn’t detect Worker process failures directly. It relies on this timeout to detect that an Activity that didn’t complete on time. So this timeout should be as short as the longest possible execution of the Activity body. Potentially long running Activities must specify heartbeat_timeout in options and heartbeat from the activity periodically for timely failure detection.



Both

Applies both execution-attempt and overall-completion bounds.

Fields

schedule_to_close: Duration

Total time the Activity is allowed to run, including retries.

start_to_close: Duration

Maximum time of a single Activity execution attempt.

Implementations