Module error

Module error 

Shared error types used across Temporal SDK crates.

Modules

application_failure_builder
Tools for manipulating the type state of ApplicationFailureBuilder.

Structs

ActivityFailureError
A normalized activity failure wrapper.
ApplicationFailure
User-authored application failure metadata that can be converted into a Temporal failure.
ApplicationFailureBuilder
Use builder syntax to set the inputs and finish with build().
CancelledError
A normalized cancellation failure.
ChildWorkflowFailureError
A normalized child-workflow execution failure wrapper.
FailurePayloads
Payloads attached to a failure, either as a deferred outbound value or decoded inbound payloads.
IncomingNexusHandlerError
A normalized nexus handler failure wrapper.
IncomingNexusOperationExecutionError
A normalized nexus operation failure wrapper.
ResetWorkflowError
A normalized reset-workflow failure.
ServerError
A normalized server failure.
TerminatedError
A normalized terminated failure.
TimeoutError
A normalized timeout failure.
WorkflowSignalFailureError
A normalized workflow signal failure wrapper.

Enums

ActivityExecutionError
Error type for activity execution outcomes.
ApplicationErrorCategory
Categorizes an ApplicationFailure to hint at how the server and tooling should treat it.
ChildWorkflowExecutionError
Error returned when a child workflow execution fails.
ChildWorkflowStartError
Error returned when starting a child workflow fails.
IncomingError
A normalized incoming Temporal failure decoded from a protobuf Failure.
OutgoingActivityError
A typed outbound activity error.
OutgoingError
A typed outbound error surface used before encoding to a Temporal failure proto.
OutgoingWorkflowError
A typed outbound workflow failure.
WorkflowSignalError
Error returned when signaling a workflow fails.