Module application_failure_builder

Module application_failure_builder 

Tools for manipulating the type state of ApplicationFailureBuilder.

See the detailed guide that describes how all the pieces here fit together.

Structs

Empty
Represents a State that has IsUnset implemented for all members.
SetCategory
Represents a State that has IsSet implemented for State::Category.
SetCause
Represents a State that has IsSet implemented for State::Cause.
SetDetails
Represents a State that has IsSet implemented for State::Details.
SetFailure
Represents a State that has IsSet implemented for State::Failure.
SetNextRetryDelay
Represents a State that has IsSet implemented for State::NextRetryDelay.
SetNonRetryable
Represents a State that has IsSet implemented for State::NonRetryable.
SetTypeName
Represents a State that has IsSet implemented for State::TypeName.

Traits

IsComplete
Marker trait that indicates that all required members are set.
IsSet
Marker trait that indicates that the member is set, i.e. at least one of its setters was called.
IsUnset
Marker trait that indicates that the member is unset, i.e. none of its setters was called.
State
Builder’s type state specifies if members are set or not (unset).