pub enum ActivityExecutionError {
Failed(ActivityFailureError),
Cancelled(CancelledError),
Serialization(PayloadConversionError),
}Expand description
Error type for activity execution outcomes.
Variants
Failed(ActivityFailureError)
The activity failed with the given failure details.
Cancelled(CancelledError)
The activity was cancelled.
Serialization(PayloadConversionError)
Failed to serialize input or deserialize result payload.
Implementations
Sourceimpl ActivityExecutionError
impl ActivityExecutionError
Sourcepub fn failure(&self) -> Option<&Failure>
pub fn failure(&self) -> Option<&Failure>
Returns the retained top-level activity failure proto, if one exists.
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause of the top-level activity failure, if any.
Sourcepub fn reason(&self) -> Option<&IncomingError>
pub fn reason(&self) -> Option<&IncomingError>
Returns the underlying failure reason for wrapper-shaped activity failures.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If this ActivityExecutionError was caused by a timeout, returns the associated
TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this ActivityExecutionError was caused by a cancellation, returns the associated
CancelledError.