pub enum CancelExternalWorkflowError {
NotFound(Box<WorkflowCancelFailureError>),
Failed(Box<WorkflowCancelFailureError>),
Serialization(PayloadConversionError),
}Expand description
Error returned when requesting cancellation of an external workflow fails.
Variants
NotFound(Box<WorkflowCancelFailureError>)
The target workflow was not found.
Failed(Box<WorkflowCancelFailureError>)
The cancellation request failed.
Serialization(PayloadConversionError)
Failed to deserialize payloads attached to the cancellation failure.
Implementations
Sourceimpl CancelExternalWorkflowError
impl CancelExternalWorkflowError
Sourcepub fn failure(&self) -> Option<&Failure>
pub fn failure(&self) -> Option<&Failure>
Returns the retained top-level cancellation failure proto, if one exists.
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause of the cancellation failure, if any.
Sourcepub fn reason(&self) -> Option<&IncomingError>
pub fn reason(&self) -> Option<&IncomingError>
Returns the normalized cancellation failure itself, if one exists.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this error was caused by cancellation, returns the associated CancelledError.