pub enum ChildWorkflowExecutionError {
Failed(Box<ChildWorkflowFailureError>),
Serialization(PayloadConversionError),
}Expand description
Error returned when a child workflow execution fails.
Variants
Failed(Box<ChildWorkflowFailureError>)
The child workflow failed.
Serialization(PayloadConversionError)
Failed to serialize input or deserialize the child workflow result payload.
Implementations
Sourceimpl ChildWorkflowExecutionError
impl ChildWorkflowExecutionError
Sourcepub fn failure(&self) -> Option<&Failure>
pub fn failure(&self) -> Option<&Failure>
Returns the retained top-level child-workflow failure proto, if one exists.
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause of the top-level child-workflow failure, if any.
Sourcepub fn reason(&self) -> Option<&IncomingError>
pub fn reason(&self) -> Option<&IncomingError>
Returns the underlying failure reason for wrapper-shaped child-workflow failures.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If this ChildWorkflowExecutionError was caused by a timeout, returns the associated
TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this ChildWorkflowExecutionError was caused by a cancellation, returns the associated
CancelledError.