#[non_exhaustive]pub enum RetryState {
Unspecified,
InProgress,
NonRetryableFailure,
Timeout,
MaximumAttemptsReached,
RetryPolicyNotSet,
InternalServerError,
CancelRequested,
Unknown,
}Expand description
Describes why a retry did or did not occur.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
No retry state was specified.
InProgress
Another retry is in progress.
NonRetryableFailure
The failure is not retryable.
Timeout
The retry timed out.
MaximumAttemptsReached
The retry policy’s maximum attempts were reached.
RetryPolicyNotSet
No retry policy was configured.
InternalServerError
An internal server error prevented retrying.
CancelRequested
Cancellation was requested.
Unknown
A state introduced by a newer server or API version.