pub struct ActivityFailureError { /* private fields */ }Expand description
A normalized activity failure wrapper.
Implementations
Sourceimpl ActivityFailureError
impl ActivityFailureError
Sourcepub fn activity_id(&self) -> &str
pub fn activity_id(&self) -> &str
Returns the activity id reported by the failure.
Sourcepub fn activity_type(&self) -> Option<&ActivityType>
pub fn activity_type(&self) -> Option<&ActivityType>
Returns the activity type, if present.
Sourcepub fn scheduled_event_id(&self) -> i64
pub fn scheduled_event_id(&self) -> i64
Returns the scheduled event id.
Sourcepub fn started_event_id(&self) -> i64
pub fn started_event_id(&self) -> i64
Returns the started event id.
Sourcepub fn retry_state(&self) -> RetryState
pub fn retry_state(&self) -> RetryState
Returns the retry state reported by core.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If this ActivityFailureError was caused by a timeout, returns the associated
TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this ActivityFailureError was caused by a cancellation, returns the associated
CancelledError.
Sourceimpl ActivityFailureError
impl ActivityFailureError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this wrapper and returns the retained proto failure.
Sourcepub fn into_parts(self) -> (Failure, Option<IncomingError>)
pub fn into_parts(self) -> (Failure, Option<IncomingError>)
Consumes this wrapper and returns the retained proto failure and normalized cause.