pub struct ApplicationFailure { /* private fields */ }Expand description
User-authored application failure metadata that can be converted into a Temporal failure.
Implementations
Sourceimpl ApplicationFailure
impl ApplicationFailure
Sourcepub fn builder(source: impl Into<Error>) -> ApplicationFailureBuilder
pub fn builder(source: impl Into<Error>) -> ApplicationFailureBuilder
Create an instance of ApplicationFailure using the builder syntax
Sourceimpl ApplicationFailure
impl ApplicationFailure
Sourcepub fn new(source: impl Into<Error>) -> Self
pub fn new(source: impl Into<Error>) -> Self
Construct a retryable application failure with no extra metadata.
Sourcepub fn non_retryable(source: impl Into<Error>) -> Self
pub fn non_retryable(source: impl Into<Error>) -> Self
Construct a non-retryable application failure with no extra metadata.
Sourcepub fn source_error(&self) -> &Error
pub fn source_error(&self) -> &Error
Returns the wrapped source error.
Sourcepub fn type_name(&self) -> Option<&str>
pub fn type_name(&self) -> Option<&str>
Returns the configured application failure type name, if any.
Sourcepub fn is_non_retryable(&self) -> bool
pub fn is_non_retryable(&self) -> bool
Returns true if this failure should be treated as non-retryable.
Sourcepub fn next_retry_delay(&self) -> Option<Duration>
pub fn next_retry_delay(&self) -> Option<Duration>
Returns the explicitly configured next retry delay, if any.
Sourcepub fn category(&self) -> ApplicationErrorCategory
pub fn category(&self) -> ApplicationErrorCategory
Returns the application error category.
Sourcepub fn details<T: TemporalDeserializable + 'static>(
&self,
) -> Result<Option<T>, PayloadConversionError>
pub fn details<T: TemporalDeserializable + 'static>( &self, ) -> Result<Option<T>, PayloadConversionError>
Returns the decoded details deserialized as the requested type, if any.
Sourcepub fn raw_details(&self) -> Option<&[Payload]>
pub fn raw_details(&self) -> Option<&[Payload]>
Returns the raw decoded details payloads, if any.
Sourcepub fn failure(&self) -> Option<&Failure>
pub fn failure(&self) -> Option<&Failure>
Returns the original failure proto when this application failure was decoded from one.
Sourcepub fn into_failure(self) -> Option<Failure>
pub fn into_failure(self) -> Option<Failure>
Consumes this application failure and returns the retained proto failure, if one exists.
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If this ApplicationFailure was caused by a timeout, returns the associated
TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this ApplicationFailure was caused by a cancellation, returns the associated
CancelledError.