pub struct CancelledError { /* private fields */ }Expand description
A normalized cancellation failure.
Implementations
Sourceimpl CancelledError
impl CancelledError
Sourcepub fn details<T: TemporalDeserializable + 'static>(
&self,
) -> Result<Option<T>, PayloadConversionError>
pub fn details<T: TemporalDeserializable + 'static>( &self, ) -> Result<Option<T>, PayloadConversionError>
Returns the cancellation details carried by the failure, deserialized as the requested type, if any.
Sourcepub fn raw_details(&self) -> Option<&[Payload]>
pub fn raw_details(&self) -> Option<&[Payload]>
Returns the raw decoded cancellation details carried by the failure, if any.
Sourceimpl CancelledError
impl CancelledError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this wrapper and returns the retained proto failure.
Sourcepub fn into_parts(self) -> (Failure, Option<IncomingError>)
pub fn into_parts(self) -> (Failure, Option<IncomingError>)
Consumes this wrapper and returns the retained proto failure and normalized cause.