pub struct ChildWorkflowFailureError { /* private fields */ }Expand description
A normalized child-workflow execution failure wrapper.
Implementations
Sourceimpl ChildWorkflowFailureError
impl ChildWorkflowFailureError
Sourcepub fn workflow_execution(&self) -> Option<&WorkflowExecution>
pub fn workflow_execution(&self) -> Option<&WorkflowExecution>
Returns the child workflow execution, if present.
Sourcepub fn workflow_type(&self) -> Option<&WorkflowType>
pub fn workflow_type(&self) -> Option<&WorkflowType>
Returns the child workflow type, if present.
Sourcepub fn initiated_event_id(&self) -> i64
pub fn initiated_event_id(&self) -> i64
Returns the initiated event id.
Sourcepub fn started_event_id(&self) -> i64
pub fn started_event_id(&self) -> i64
Returns the started event id.
Sourcepub fn retry_state(&self) -> RetryState
pub fn retry_state(&self) -> RetryState
Returns the retry state reported by core.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If this ChildWorkflowFailureError was caused by a timeout, returns the associated
TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If this ChildWorkflowFailureError was caused by a cancellation, returns the associated
CancelledError.
Sourceimpl ChildWorkflowFailureError
impl ChildWorkflowFailureError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this wrapper and returns the retained proto failure.
Sourcepub fn into_parts(self) -> (Failure, Option<IncomingError>)
pub fn into_parts(self) -> (Failure, Option<IncomingError>)
Consumes this wrapper and returns the retained proto failure and normalized cause.