pub struct ServerError { /* private fields */ }Expand description
A normalized server failure.
Implementations
Sourceimpl ServerError
impl ServerError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this wrapper and returns the retained proto failure.
Sourcepub fn into_parts(self) -> (Failure, Option<IncomingError>)
pub fn into_parts(self) -> (Failure, Option<IncomingError>)
Consumes this wrapper and returns the retained proto failure and normalized cause.