pub struct TimeoutError { /* private fields */ }Expand description
A normalized timeout failure.
Implementations
Sourceimpl TimeoutError
impl TimeoutError
Sourcepub fn timeout_type(&self) -> TimeoutType
pub fn timeout_type(&self) -> TimeoutType
Returns the timeout kind described by the failure.
Sourcepub fn last_heartbeat_details<T: TemporalDeserializable + 'static>(
&self,
) -> Result<Option<T>, PayloadConversionError>
pub fn last_heartbeat_details<T: TemporalDeserializable + 'static>( &self, ) -> Result<Option<T>, PayloadConversionError>
Returns the last heartbeat details carried by the timeout, if any.
Sourcepub fn raw_last_heartbeat_details(&self) -> Option<&[Payload]>
pub fn raw_last_heartbeat_details(&self) -> Option<&[Payload]>
Returns the raw decoded heartbeat details carried by the timeout, if any.
Sourceimpl TimeoutError
impl TimeoutError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this wrapper and returns the retained proto failure.
Sourcepub fn into_parts(self) -> (Failure, Option<IncomingError>)
pub fn into_parts(self) -> (Failure, Option<IncomingError>)
Consumes this wrapper and returns the retained proto failure and normalized cause.