pub async fn encode_payloads<M: PayloadVisitable + Send>(
msg: &mut M,
codec: &(dyn PayloadCodec + Send + Sync),
context: &SerializationContextData,
)Expand description
Encode all payloads in a message using the given codec.
pub async fn encode_payloads<M: PayloadVisitable + Send>(
msg: &mut M,
codec: &(dyn PayloadCodec + Send + Sync),
context: &SerializationContextData,
)Encode all payloads in a message using the given codec.