Module protos

Module protos 

Contains the protobuf definitions used as arguments to and return values from interactions with the Temporal Core SDK. Language SDK authors can generate structs using the proto definitions that will match the generated structs in this module.

Modules

protos
Contains the protobuf definitions used as arguments to and return values from interactions with the Temporal Core SDK. Language SDK authors can generate structs using the proto definitions that will match the generated structs in this module.

Structs

TaskToken
Type-safe wrapper for task token bytes

Statics

ENCODING_PAYLOAD_KEY
Payload metadata key that identifies the encoding format.
JSON_ENCODING_VAL
The metadata value for JSON-encoded payloads.
PATCHED_MARKER_DETAILS_KEY
The details key used in patched marker payloads.
VERSION_SEARCH_ATTR_KEY
The search attribute key used when registering change versions

Functions

camel_case_to_screaming_snake
Case conversion, used for json -> proto enum string conversion
proto_ts_to_system_time
Convert a protobuf prost_types::Timestamp to a std::time::SystemTime.