pub struct ActivityResolution {
pub status: Option<Status>,
}Expand description
Used to report activity resolutions to lang. IE: This is what the activities are resolved with in the workflow.
Fields
status: Option<Status>Implementations
Sourceimpl ActivityResolution
impl ActivityResolution
Sourcepub fn success_payload_or_error(self) -> Result<Option<Payload>, Error>
pub fn success_payload_or_error(self) -> Result<Option<Payload>, Error>
Extract an activity’s payload if it completed successfully, or return an error for all other outcomes.
pub fn unwrap_ok_payload(self) -> Payload
pub fn completed_ok(&self) -> bool
pub fn failed(&self) -> bool
pub fn timed_out(&self) -> Option<TimeoutType>
pub fn cancelled(&self) -> bool
Sourcepub fn unwrap_failure(self) -> APIFailure
pub fn unwrap_failure(self) -> APIFailure
If this resolution is any kind of failure, return the inner failure details. Panics if the activity succeeded, is in backoff, or this resolution is malformed.