#[repr(i32)]pub enum VersioningIntent {
Unspecified = 0,
Compatible = 1,
Default = 2,
}Expand description
An indication of user’s intent concerning what Build ID versioning approach should be used for a specific command
Variants
Unspecified = 0
Indicates that core should choose the most sensible default behavior for the type of command, accounting for whether the command will be run on the same task queue as the current worker.
Compatible = 1
Indicates that the command should run on a worker with compatible version if possible. It may not be possible if the target task queue does not also have knowledge of the current worker’s build ID.
Default = 2
Indicates that the command should run on the target task queue’s current overall-default build ID.
Implementations
Sourceimpl VersioningIntent
impl VersioningIntent
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.