pub struct BatchOperationUpdateActivityOptions {
pub identity: String,
pub activity_options: Option<ActivityOptions>,
pub update_mask: Option<FieldMask>,
pub restore_original: bool,
pub activity: Option<Activity>,
}Expand description
BatchOperationUpdateActivityOptions sends an update-activity-options requests in a batch. NOTE: keep in sync with temporal.api.workflowservice.v1.UpdateActivityRequest
Fields
identity: StringThe identity of the worker/client.
activity_options: Option<ActivityOptions>Update Activity options. Partial updates are accepted and controlled by update_mask.
update_mask: Option<FieldMask>Controls which fields from activity_options will be applied
restore_original: boolIf set, the activity options will be restored to the default. Default options are then options activity was created with. They are part of the first ActivityTaskScheduled event. This flag cannot be combined with any other option; if you supply restore_original together with other options, the request will be rejected.
activity: Option<Activity>The activity to update. If match_all is set to true, all activities will be updated.