pub struct AddUserGroupMemberRequest {
pub group_id: String,
pub member_id: Option<UserGroupMemberId>,
pub async_operation_id: String,
}Fields
group_id: StringThe id of the group to add the member for.
member_id: Option<UserGroupMemberId>The member id to add to the group.
async_operation_id: StringThe id to use for this async operation. Optional, if not provided a random id will be generated.