pub struct DeleteConnectivityRuleRequest {
pub connectivity_rule_id: String,
pub resource_version: String,
pub async_operation_id: String,
}Fields
connectivity_rule_id: StringThe ID of the connectivity rule that need be deleted, required.
resource_version: StringThe resource version which should be the same from the the db, required The latest version can be found in the GetConnectivityRule operation response
async_operation_id: StringThe id to use for this async operation. Optional, if not provided a random id will be generated.