pub struct DeleteServiceAccountRequest {
pub service_account_id: String,
pub resource_version: String,
pub async_operation_id: String,
}Fields
service_account_id: StringThe ID of the service account to delete;
resource_version: StringThe version of the service account for which this update is intended for. The latest version can be found in the GetServiceAccount response.
async_operation_id: StringThe ID to use for this async operation - optional.