pub struct DeleteUserRequest {
pub user_id: String,
pub resource_version: String,
pub async_operation_id: String,
}Fields
user_id: StringThe id of the user to delete
resource_version: StringThe version of the user for which this delete is intended for The latest version can be found in the GetUser operation response
async_operation_id: StringThe id to use for this async operation - optional