pub struct GetApiKeysRequest {
pub page_size: i32,
pub page_token: String,
pub owner_id: String,
pub owner_type_deprecated: String,
pub owner_type: i32,
}Fields
page_size: i32The requested size of the page to retrieve - optional. Cannot exceed 1000. Defaults to 100.
page_token: StringThe page token if this is continuing from another response - optional.
owner_id: StringFilter api keys by owner id - optional.
owner_type_deprecated: String👎Deprecated
Filter api keys by owner type - optional. Possible values: user, service-account
owner_type: i32Filter api keys by owner type - optional. temporal:enums:replaces=owner_type_deprecated
Implementations
Sourceimpl GetApiKeysRequest
impl GetApiKeysRequest
Sourcepub fn owner_type(&self) -> OwnerType
pub fn owner_type(&self) -> OwnerType
Returns the enum value of owner_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_owner_type(&mut self, value: OwnerType)
pub fn set_owner_type(&mut self, value: OwnerType)
Sets owner_type to the provided enum value.