pub struct GetAuditLogsRequest {
pub page_size: i32,
pub page_token: String,
pub start_time_inclusive: Option<Timestamp>,
pub end_time_exclusive: Option<Timestamp>,
}Fields
page_size: i32The requested size of the page to retrieve - optional. Cannot exceed 1000. Defaults to 100.
page_token: StringThe page token if this is continuing from another response - optional.
start_time_inclusive: Option<Timestamp>Filter for UTC time >= (defaults to 30 days ago) - optional.
end_time_exclusive: Option<Timestamp>Filter for UTC time < (defaults to current time) - optional.