pub struct GetUsageRequest {
pub start_time_inclusive: Option<Timestamp>,
pub end_time_exclusive: Option<Timestamp>,
pub page_size: i32,
pub page_token: String,
}Fields
start_time_inclusive: Option<Timestamp>Filter for UTC time >= - optional. Defaults to: start of the current month. Must be: within the last 90 days from the current date. Must be: midnight UTC time.
end_time_exclusive: Option<Timestamp>Filter for UTC time < - optional. Defaults to: start of the next UTC day. Must be: within the last 90 days from the current date. Must be: midnight UTC time.
page_size: i32The requested size of the page to retrieve - optional. Each count corresponds to a single object - per day per namespace Cannot exceed 1000. Defaults to 100.
page_token: StringThe page token if this is continuing from another response - optional.