pub struct GetUserGroupsRequest {
pub page_size: i32,
pub page_token: String,
pub namespace: String,
pub display_name: String,
pub google_group: Option<GoogleGroupFilter>,
pub scim_group: Option<ScimGroupFilter>,
}Fields
page_size: i32The requested size of the page to retrieve - optional. Cannot exceed 1000. Defaults to 100.
page_token: StringThe page token if this is continuing from another response - optional.
namespace: StringFilter groups by the namespace they have access to - optional.
display_name: StringFilter groups by the display name - optional.
google_group: Option<GoogleGroupFilter>Filter groups by the google group specification - optional.
scim_group: Option<ScimGroupFilter>Filter groups by the SCIM group specification - optional.