pub struct GetUsersRequest {
pub page_size: i32,
pub page_token: String,
pub email: String,
pub namespace: String,
}Fields
page_size: i32The requested size of the page to retrieve - optional. Cannot exceed 1000. Defaults to 100.
page_token: StringThe page token if this is continuing from another response - optional.
email: StringFilter users by email address - optional.
namespace: StringFilter users by the namespace they have access to - optional.