pub struct UpdateAccountRequest {
pub spec: Option<AccountSpec>,
pub resource_version: String,
pub async_operation_id: String,
}Fields
spec: Option<AccountSpec>The updated account specification to apply.
resource_version: StringThe version of the account for which this update is intended for. The latest version can be found in the GetAccount operation response.
async_operation_id: StringThe id to use for this async operation. Optional, if not provided a random id will be generated.