pub struct UpdateApiKeyRequest {
pub key_id: String,
pub spec: Option<ApiKeySpec>,
pub resource_version: String,
pub async_operation_id: String,
}Fields
key_id: StringThe id of the api key to update.
spec: Option<ApiKeySpec>The new api key specification.
resource_version: StringThe version of the api key for which this update is intended for. The latest version can be found in the GetApiKey operation response.
async_operation_id: StringThe id to use for this async operation - optional.