pub struct UpdateUserGroupRequest {
pub group_id: String,
pub spec: Option<UserGroupSpec>,
pub resource_version: String,
pub async_operation_id: String,
}Fields
group_id: StringThe id of the group to update.
spec: Option<UserGroupSpec>The new group specification.
resource_version: StringThe version of the group for which this update is intended for. The latest version can be found in the GetGroup operation response.
async_operation_id: StringThe id to use for this async operation. Optional, if not provided a random id will be generated.