pub struct UpdateUserRequest {
pub user_id: String,
pub spec: Option<UserSpec>,
pub resource_version: String,
pub async_operation_id: String,
}Fields
user_id: StringThe id of the user to update
spec: Option<UserSpec>The new user specification
resource_version: StringThe version of the user for which this update is intended for The latest version can be found in the GetUser operation response
async_operation_id: StringThe id to use for this async operation - optional