ApiKeySpec

Struct ApiKeySpec 

pub struct ApiKeySpec {
    pub owner_id: String,
    pub owner_type_deprecated: String,
    pub owner_type: i32,
    pub display_name: String,
    pub description: String,
    pub expiry_time: Option<Timestamp>,
    pub disabled: bool,
}

Fields

owner_id: String

The id of the owner to create the API key for. The owner id is immutable. Once set during creation, it cannot be changed. The owner id is the id of the user when the owner type is user. The owner id is the id of the service account when the owner type is service account.

owner_type_deprecated: String
👎Deprecated

The type of the owner to create the API key for. The owner type is immutable. Once set during creation, it cannot be changed. Possible values: user, service-account. Deprecated: Not supported after v0.3.0 api version. Use owner_type instead. temporal:versioning:max_version=v0.3.0

owner_type: i32

The type of the owner to create the API key for. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=owner_type_deprecated

display_name: String

The display name of the API key.

description: String

The description of the API key.

expiry_time: Option<Timestamp>

The expiry time of the API key.

disabled: bool

True if the API key is disabled.

Implementations

Source

impl ApiKeySpec

pub fn owner_type(&self) -> OwnerType

Returns the enum value of owner_type, or the default if the field is set to an invalid enum value.

pub fn set_owner_type(&mut self, value: OwnerType)

Sets owner_type to the provided enum value.