NamespaceAccess

Struct NamespaceAccess 

pub struct NamespaceAccess {
    pub permission_deprecated: String,
    pub permission: i32,
}

Fields

permission_deprecated: String
👎Deprecated

The permission to the namespace, should be one of [admin, write, read] admin - gives full access to the namespace, including assigning namespace access to other users write - gives write access to the namespace configuration and workflows within the namespace read - gives read only access to the namespace configuration and workflows within the namespace Deprecated: Not supported after v0.3.0 api version. Use permission instead. temporal:versioning:max_version=v0.3.0

permission: i32

The permission to the namespace. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=permission_deprecated

Implementations

Source

impl NamespaceAccess

pub fn permission(&self) -> Permission

Returns the enum value of permission, or the default if the field is set to an invalid enum value.

pub fn set_permission(&mut self, value: Permission)

Sets permission to the provided enum value.