pub struct ServiceAccount {
pub id: String,
pub resource_version: String,
pub spec: Option<ServiceAccountSpec>,
pub state_deprecated: String,
pub state: i32,
pub async_operation_id: String,
pub created_time: Option<Timestamp>,
pub last_modified_time: Option<Timestamp>,
}Fields
id: StringThe id of the service account.
resource_version: StringThe current version of the service account specification. The next update operation will have to include this version.
spec: Option<ServiceAccountSpec>The service account specification.
state_deprecated: StringThe current state of the service account. Possible values: activating, activationfailed, active, updating, updatefailed, deleting, deletefailed, deleted, suspending, suspendfailed, suspended. For any failed state, reach out to Temporal Cloud support for remediation. Deprecated: Not supported after v0.3.0 api version. Use state instead. temporal:versioning:max_version=v0.3.0
state: i32The current state of the service account. For any failed state, reach out to Temporal Cloud support for remediation. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=state_deprecated
async_operation_id: StringThe id of the async operation that is creating/updating/deleting the service account, if any.
created_time: Option<Timestamp>The date and time when the service account was created.
last_modified_time: Option<Timestamp>The date and time when the service account was last modified Will not be set if the service account has never been modified.
Implementations
Sourceimpl ServiceAccount
impl ServiceAccount
Sourcepub fn state(&self) -> ResourceState
pub fn state(&self) -> ResourceState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ResourceState)
pub fn set_state(&mut self, value: ResourceState)
Sets state to the provided enum value.