pub struct ServiceAccountSpec {
pub name: String,
pub access: Option<Access>,
pub namespace_scoped_access: Option<NamespaceScopedAccess>,
pub description: String,
}Fields
name: StringThe name associated with the service account. The name is mutable, but must be unique across all your active service accounts.
access: Option<Access>Note: one of Access or NamespaceScopedAccess must be provided, but not both.
The access assigned to the service account.
If set, creates an account scoped service account.
The access is mutable.
namespace_scoped_access: Option<NamespaceScopedAccess>The namespace scoped access assigned to the service account.
If set, creates a namespace scoped service account (limited to a single namespace).
The namespace scoped access is partially mutable.
Refer to NamespaceScopedAccess for details.
description: StringThe description associated with the service account - optional. The description is mutable.