pub struct CodecServerSpec {
pub endpoint: String,
pub pass_access_token: bool,
pub include_cross_origin_credentials: bool,
pub custom_error_message: Option<CustomErrorMessage>,
}Fields
endpoint: StringThe codec server endpoint.
pass_access_token: boolWhether to pass the user access token with your endpoint.
include_cross_origin_credentials: boolWhether to include cross-origin credentials.
custom_error_message: Option<CustomErrorMessage>A custom error message to display for remote codec server errors. temporal:versioning:min_version=v0.5.1