#[repr(i32)]pub enum ResourceState {
Unspecified = 0,
Activating = 1,
ActivationFailed = 2,
Active = 3,
Updating = 4,
UpdateFailed = 5,
Deleting = 6,
DeleteFailed = 7,
Deleted = 8,
Suspended = 9,
Expired = 10,
}Variants
Unspecified = 0
Activating = 1
The resource is being activated.
ActivationFailed = 2
The resource failed to activate. This is an error state. Reach out to support for remediation.
Active = 3
The resource is active and ready to use.
Updating = 4
The resource is being updated.
UpdateFailed = 5
The resource failed to update. This is an error state. Reach out to support for remediation.
Deleting = 6
The resource is being deleted.
DeleteFailed = 7
The resource failed to delete. This is an error state. Reach out to support for remediation.
Deleted = 8
The resource has been deleted.
Suspended = 9
The resource is suspended and not available for use. Reach out to support for remediation.
Expired = 10
The resource has expired and is no longer available for use.
Implementations
Sourceimpl ResourceState
impl ResourceState
Sourceimpl ResourceState
impl ResourceState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.