pub struct Command {
pub command_type: i32,
pub user_metadata: Option<UserMetadata>,
pub attributes: Option<Attributes>,
}Fields
command_type: i32user_metadata: Option<UserMetadata>Metadata on the command. This is sometimes carried over to the history event if one is created as a result of the command. Most commands won’t have this information, and how this information is used is dependent upon the interface that reads it.
Current well-known uses:
- start_child_workflow_execution_command_attributes - populates temporal.api.workflow.v1.WorkflowExecutionInfo.user_metadata where the summary and details are used by user interfaces to show fixed as-of-start workflow summary and details.
- start_timer_command_attributes - populates temporal.api.history.v1.HistoryEvent for timer started where the summary is used to identify the timer.
attributes: Option<Attributes>The command details. The type must match that in command_type.
Implementations
Sourceimpl Command
impl Command
Sourcepub fn command_type(&self) -> CommandType
pub fn command_type(&self) -> CommandType
Returns the enum value of command_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command_type(&mut self, value: CommandType)
pub fn set_command_type(&mut self, value: CommandType)
Sets command_type to the provided enum value.