pub struct ModifyWorkflowPropertiesCommandAttributes {
pub upserted_memo: Option<Memo>,
}Fields
upserted_memo: Option<Memo>If set, update the workflow memo with the provided values. The values will be merged with the existing memo. If the user wants to delete values, a default/empty Payload should be used as the value for the key being deleted.