StartChildWorkflowExecutionCommandAttributes

Struct StartChildWorkflowExecutionCommandAttributes 

pub struct StartChildWorkflowExecutionCommandAttributes {
Show 18 fields pub namespace: String, pub workflow_id: String, pub workflow_type: Option<WorkflowType>, pub task_queue: Option<TaskQueue>, pub input: Option<Payloads>, pub workflow_execution_timeout: Option<Duration>, pub workflow_run_timeout: Option<Duration>, pub workflow_task_timeout: Option<Duration>, pub parent_close_policy: i32, pub control: String, pub workflow_id_reuse_policy: i32, pub retry_policy: Option<RetryPolicy>, pub cron_schedule: String, pub header: Option<Header>, pub memo: Option<Memo>, pub search_attributes: Option<SearchAttributes>, pub inherit_build_id: bool, pub priority: Option<Priority>,
}

Fields

namespace: Stringworkflow_id: Stringworkflow_type: Option<WorkflowType>task_queue: Option<TaskQueue>input: Option<Payloads>workflow_execution_timeout: Option<Duration>

Total workflow execution timeout including retries and continue as new.

workflow_run_timeout: Option<Duration>

Timeout of a single workflow run.

workflow_task_timeout: Option<Duration>

Timeout of a single workflow task.

parent_close_policy: i32

Default: PARENT_CLOSE_POLICY_TERMINATE.

control: Stringworkflow_id_reuse_policy: i32

Default: WORKFLOW_ID_REUSE_POLICY_ALLOW_DUPLICATE.

retry_policy: Option<RetryPolicy>cron_schedule: String

Establish a cron schedule for the child workflow.

header: Option<Header>memo: Option<Memo>search_attributes: Option<SearchAttributes>inherit_build_id: bool
👎Deprecated

If this is set, the child workflow inherits the Build ID of the parent. Otherwise, the assignment rules of the child’s Task Queue will be used to independently assign a Build ID to it. Deprecated. Only considered for versioning v0.2.

priority: Option<Priority>

Priority metadata. If this message is not present, or any fields are not present, they inherit the values from the workflow.

Implementations

Source

impl StartChildWorkflowExecutionCommandAttributes

pub fn parent_close_policy(&self) -> ParentClosePolicy

Returns the enum value of parent_close_policy, or the default if the field is set to an invalid enum value.

pub fn set_parent_close_policy(&mut self, value: ParentClosePolicy)

Sets parent_close_policy to the provided enum value.

pub fn workflow_id_reuse_policy(&self) -> WorkflowIdReusePolicy

Returns the enum value of workflow_id_reuse_policy, or the default if the field is set to an invalid enum value.

pub fn set_workflow_id_reuse_policy(&mut self, value: WorkflowIdReusePolicy)

Sets workflow_id_reuse_policy to the provided enum value.