pub struct StartTimerCommandAttributes {
pub timer_id: String,
pub start_to_fire_timeout: Option<Duration>,
}Fields
timer_id: StringAn id for the timer, currently live timers must have different ids. Typically autogenerated by the SDK.
start_to_fire_timeout: Option<Duration>How long until the timer fires, producing a TIMER_FIRED event.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)