pub struct UpsertWorkflowSearchAttributesCommandAttributes {
pub search_attributes: Option<SearchAttributes>,
}Fields
search_attributes: Option<SearchAttributes>Trait Implementations
Sourceimpl Clone for UpsertWorkflowSearchAttributesCommandAttributes
impl Clone for UpsertWorkflowSearchAttributesCommandAttributes
Sourcefn clone(&self) -> UpsertWorkflowSearchAttributesCommandAttributes
fn clone(&self) -> UpsertWorkflowSearchAttributesCommandAttributes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<UpsertWorkflowSearchAttributesCommandAttributes> for Attributes
impl From<UpsertWorkflowSearchAttributesCommandAttributes> for Attributes
Sourcefn from(value: UpsertWorkflowSearchAttributesCommandAttributes) -> Self
fn from(value: UpsertWorkflowSearchAttributesCommandAttributes) -> Self
Converts to this type from the input type.
Sourceimpl Message for UpsertWorkflowSearchAttributesCommandAttributes
impl Message for UpsertWorkflowSearchAttributesCommandAttributes
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for UpsertWorkflowSearchAttributesCommandAttributes
impl Name for UpsertWorkflowSearchAttributesCommandAttributes
Sourceconst NAME: &'static str = "UpsertWorkflowSearchAttributesCommandAttributes"
const NAME: &'static str = "UpsertWorkflowSearchAttributesCommandAttributes"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "temporal.api.command.v1"
const PACKAGE: &'static str = "temporal.api.command.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for UpsertWorkflowSearchAttributesCommandAttributes
impl PartialEq for UpsertWorkflowSearchAttributesCommandAttributes
Sourcefn eq(&self, other: &UpsertWorkflowSearchAttributesCommandAttributes) -> bool
fn eq(&self, other: &UpsertWorkflowSearchAttributesCommandAttributes) -> bool
Tests for
self and other values to be equal, and is used by ==.impl PayloadVisitable for UpsertWorkflowSearchAttributesCommandAttributes
impl PayloadVisitable for UpsertWorkflowSearchAttributesCommandAttributes
fn visit_payloads_mut<'a>(
&'a mut self,
visitor: &'a mut (dyn AsyncPayloadVisitor + Send),
) -> BoxFuture<'a, ()>
fn visit_payloads_mut<'a>( &'a mut self, visitor: &'a mut (dyn AsyncPayloadVisitor + Send), ) -> BoxFuture<'a, ()>
Visit all payload fields in this message.
The visitor is called once per field, receiving the field’s payload(s).
impl StructuralPartialEq for UpsertWorkflowSearchAttributesCommandAttributes