pub struct RetryPolicy {
pub initial_interval: Option<Duration>,
pub backoff_coefficient: f64,
pub maximum_interval: Option<Duration>,
pub maximum_attempts: i32,
pub non_retryable_error_types: Vec<String>,
}Expand description
How retries ought to be handled, usable by both workflows and activities
Fields
initial_interval: Option<Duration>Interval of the first retry. If retryBackoffCoefficient is 1.0 then it is used for all retries.
backoff_coefficient: f64Coefficient used to calculate the next retry interval. The next retry interval is previous interval multiplied by the coefficient. Must be 1 or larger.
maximum_interval: Option<Duration>Maximum interval between retries. Exponential backoff leads to interval increase. This value is the cap of the increase. Default is 100x of the initial interval.
maximum_attempts: i32Maximum number of attempts. When exceeded the retries stop even if not expired yet. 1 disables retries. 0 means unlimited (up to the timeouts)
non_retryable_error_types: Vec<String>Non-Retryable errors types. Will stop retrying if the error type matches this list. Note that this is not a substring match, the error type (not message) must match exactly.