pub struct SearchAttributes {
pub indexed_fields: HashMap<String, Payload>,
}Expand description
A user-defined set of indexed fields that are used/exposed when listing/searching workflows. The payload is not serialized in a user-defined way.
Fields
indexed_fields: HashMap<String, Payload>Trait Implementations
Sourceimpl Clone for SearchAttributes
impl Clone for SearchAttributes
Sourcefn clone(&self) -> SearchAttributes
fn clone(&self) -> SearchAttributes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchAttributes
impl Debug for SearchAttributes
Sourceimpl Default for SearchAttributes
impl Default for SearchAttributes
impl<'de> Deserialize<'de> for SearchAttributes
impl<'de> Deserialize<'de> for SearchAttributes
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<SearchAttributes> for HashMap<String, Payload>
impl From<SearchAttributes> for HashMap<String, Payload>
Sourcefn from(h: SearchAttributes) -> Self
fn from(h: SearchAttributes) -> Self
Converts to this type from the input type.
Sourceimpl Message for SearchAttributes
impl Message for SearchAttributes
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for SearchAttributes
impl Name for SearchAttributes
Sourceconst NAME: &'static str = "SearchAttributes"
const NAME: &'static str = "SearchAttributes"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "temporal.api.common.v1"
const PACKAGE: &'static str = "temporal.api.common.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for SearchAttributes
impl PartialEq for SearchAttributes
impl PayloadVisitable for SearchAttributes
impl PayloadVisitable for SearchAttributes
fn visit_payloads_mut<'a>(
&'a mut self,
visitor: &'a mut (dyn AsyncPayloadVisitor + Send),
) -> BoxFuture<'a, ()>
fn visit_payloads_mut<'a>( &'a mut self, visitor: &'a mut (dyn AsyncPayloadVisitor + Send), ) -> BoxFuture<'a, ()>
Visit all payload fields in this message.
The visitor is called once per field, receiving the field’s payload(s).
impl Serialize for SearchAttributes
impl Serialize for SearchAttributes
impl StructuralPartialEq for SearchAttributes