pub struct WorkerVersionCapabilities {
pub build_id: String,
pub use_versioning: bool,
pub deployment_series_name: String,
}Expand description
Identifies the version that a worker is compatible with when polling or identifying itself, and whether or not this worker is opting into the build-id based versioning feature. This is used by matching to determine which workers ought to receive what tasks. Deprecated. Use WorkerDeploymentOptions instead.
Fields
build_id: StringAn opaque whole-worker identifier
use_versioning: boolIf set, the worker is opting in to worker versioning, and wishes to only receive appropriate tasks.
deployment_series_name: StringMust be sent if user has set a deployment series name (versioning-3).