pub struct WorkerVersionStamp {
pub build_id: String,
pub use_versioning: bool,
}Expand description
Deprecated. This message is replaced with Deployment and VersioningBehavior.
Identifies the version(s) of a worker that processed a task
Fields
build_id: StringAn opaque whole-worker identifier. Replaces the deprecated binary_checksum field when this
message is included in requests which previously used that.
use_versioning: boolIf set, the worker is opting in to worker versioning. Otherwise, this is used only as a marker for workflow reset points and the BuildIDs search attribute.