pub struct RoutingConfig {
pub current_deployment_version: Option<WorkerDeploymentVersion>,
pub current_version: String,
pub ramping_deployment_version: Option<WorkerDeploymentVersion>,
pub ramping_version: String,
pub ramping_version_percentage: f32,
pub current_version_changed_time: Option<Timestamp>,
pub ramping_version_changed_time: Option<Timestamp>,
pub ramping_version_percentage_changed_time: Option<Timestamp>,
pub revision_number: i64,
}Fields
current_deployment_version: Option<WorkerDeploymentVersion>Specifies which Deployment Version should receive new workflow executions and tasks of
existing unversioned or AutoUpgrade workflows.
Nil value means no Version in this Deployment (except Ramping Version, if present) receives traffic other than tasks of previously Pinned workflows. In absence of a Current Version, remaining traffic after any ramp (if set) goes to unversioned workers (those with UNVERSIONED (or unspecified) WorkerVersioningMode.).
Note: Current Version is overridden by the Ramping Version for a portion of traffic when ramp percentage
is non-zero (see ramping_deployment_version and ramping_version_percentage).
current_version: StringDeprecated. Use current_deployment_version.
ramping_deployment_version: Option<WorkerDeploymentVersion>When ramp percentage is non-zero, that portion of traffic is shifted from the Current Version to the Ramping Version.
Must always be different from current_deployment_version unless both are nil.
Nil value represents all the unversioned workers (those with UNVERSIONED (or unspecified) WorkerVersioningMode.)
Note that it is possible to ramp from one Version to another Version, or from unversioned
workers to a particular Version, or from a particular Version to unversioned workers.
ramping_version: StringDeprecated. Use ramping_deployment_version.
ramping_version_percentage: f32Percentage of tasks that are routed to the Ramping Version instead of the Current Version. Valid range: [0, 100]. A 100% value means the Ramping Version is receiving full traffic but not yet “promoted” to be the Current Version, likely due to pending validations. A 0% value means the Ramping Version is receiving no traffic.
current_version_changed_time: Option<Timestamp>Last time current version was changed.
ramping_version_changed_time: Option<Timestamp>Last time ramping version was changed. Not updated if only the ramp percentage changes.
ramping_version_percentage_changed_time: Option<Timestamp>Last time ramping version percentage was changed. If ramping version is changed, this is also updated, even if the percentage stays the same.
revision_number: i64Monotonically increasing value which is incremented on every mutation to any field of this message to achieve eventual consistency between task queues and their partitions.