WorkerDeploymentOptions

Struct WorkerDeploymentOptions 

pub struct WorkerDeploymentOptions {
    pub deployment_name: String,
    pub build_id: String,
    pub worker_versioning_mode: i32,
}
Worker Deployment options set in SDK that need to be sent to server in every poll. Experimental. Worker Deployments are experimental and might significantly change in the future.

Fields

deployment_name: String

Required when worker_versioning_mode==VERSIONED.

build_id: String

The Build ID of the worker. Required when worker_versioning_mode==VERSIONED, in which case, the worker will be part of a Deployment Version.

worker_versioning_mode: i32

Required. Versioning Mode for this worker. Must be the same for all workers with the same deployment_name and build_id combination, across all Task Queues. When worker_versioning_mode==VERSIONED, the worker will be part of a Deployment Version.

Implementations

Source

impl WorkerDeploymentOptions

pub fn worker_versioning_mode(&self) -> WorkerVersioningMode

Returns the enum value of worker_versioning_mode, or the default if the field is set to an invalid enum value.

pub fn set_worker_versioning_mode(&mut self, value: WorkerVersioningMode)

Sets worker_versioning_mode to the provided enum value.