BuildIdTaskReachability

Enum BuildIdTaskReachability 

#[repr(i32)]
pub enum BuildIdTaskReachability { Unspecified = 0, Reachable = 1, ClosedWorkflowsOnly = 2, Unreachable = 3, }
Specifies which category of tasks may reach a versioned worker of a certain Build ID.

Task Reachability is eventually consistent; there may be a delay (up to few minutes) until it converges to the most accurate value but it is designed in a way to take the more conservative side until it converges. For example REACHABLE is more conservative than CLOSED_WORKFLOWS_ONLY.

Note: future activities who inherit their workflow’s Build ID but not its Task Queue will not be accounted for reachability as server cannot know if they’ll happen as they do not use assignment rules of their Task Queue. Same goes for Child Workflows or Continue-As-New Workflows who inherit the parent/previous workflow’s Build ID but not its Task Queue. In those cases, make sure to query reachability for the parent/previous workflow’s Task Queue as well.

Variants



Unspecified = 0

Task reachability is not reported



Reachable = 1

Build ID may be used by new workflows or activities (base on versioning rules), or there MAY be open workflows or backlogged activities assigned to it.



ClosedWorkflowsOnly = 2

Build ID does not have open workflows and is not reachable by new workflows, but MAY have closed workflows within the namespace retention period. Not applicable to activity-only task queues.



Unreachable = 3

Build ID is not used for new executions, nor it has been used by any existing execution within the retention period.

Implementations

Source

impl BuildIdTaskReachability

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of BuildIdTaskReachability.

pub fn from_i32(value: i32) -> Option<BuildIdTaskReachability>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a BuildIdTaskReachability, or None if value is not a valid variant.

Source

impl BuildIdTaskReachability

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.