#[repr(i32)]pub enum DescribeTaskQueueMode {
Unspecified = 0,
Enhanced = 1,
}Variants
Unspecified = 0
Unspecified means legacy behavior.
Enhanced = 1
Enhanced mode reports aggregated results for all partitions, supports Build IDs, and reports richer info.
Implementations
Sourceimpl DescribeTaskQueueMode
impl DescribeTaskQueueMode
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of DescribeTaskQueueMode.
Sourcepub fn from_i32(value: i32) -> Option<DescribeTaskQueueMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<DescribeTaskQueueMode>
Converts an i32 to a DescribeTaskQueueMode, or None if value is not a valid variant.
Sourceimpl DescribeTaskQueueMode
impl DescribeTaskQueueMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.