PendingWorkflowTaskState

Enum PendingWorkflowTaskState 

#[repr(i32)]
pub enum PendingWorkflowTaskState { Unspecified = 0, Scheduled = 1, Started = 2, }

Variants



Unspecified = 0



Scheduled = 1



Started = 2

Implementations

Source

impl PendingWorkflowTaskState

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PendingWorkflowTaskState.

pub fn from_i32(value: i32) -> Option<PendingWorkflowTaskState>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PendingWorkflowTaskState, or None if value is not a valid variant.

Source

impl PendingWorkflowTaskState

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.