#[repr(i32)]pub enum QueryRejectCondition {
Unspecified = 0,
None = 1,
NotOpen = 2,
NotCompletedCleanly = 3,
}Variants
Unspecified = 0
None = 1
None indicates that query should not be rejected.
NotOpen = 2
NotOpen indicates that query should be rejected if workflow is not open.
NotCompletedCleanly = 3
NotCompletedCleanly indicates that query should be rejected if workflow did not complete cleanly.
Implementations
Sourceimpl QueryRejectCondition
impl QueryRejectCondition
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of QueryRejectCondition.
Sourcepub fn from_i32(value: i32) -> Option<QueryRejectCondition>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<QueryRejectCondition>
Converts an i32 to a QueryRejectCondition, or None if value is not a valid variant.
Sourceimpl QueryRejectCondition
impl QueryRejectCondition
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.