TaskQueueKind

Enum TaskQueueKind 

#[repr(i32)]
pub enum TaskQueueKind { Unspecified = 0, Normal = 1, Sticky = 2, }

Variants



Unspecified = 0

Tasks from any non workflow task may be unspecified.

Task queue kind is used to differentiate whether a workflow task queue is sticky or normal. If a task is not a workflow task, Task queue kind will sometimes be unspecified.



Normal = 1

Tasks from a normal workflow task queue always include complete workflow history

The task queue specified by the user is always a normal task queue. There can be as many workers as desired for a single normal task queue. All those workers may pick up tasks from that queue.



Sticky = 2

A sticky queue only includes new history since the last workflow task, and they are per-worker.

Sticky queues are created dynamically by each worker during their start up. They only exist for the lifetime of the worker process. Tasks in a sticky task queue are only available to the worker that created the sticky queue.

Sticky queues are only for workflow tasks. There are no sticky task queues for activities.

Implementations

Source

impl TaskQueueKind

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of TaskQueueKind.

pub fn from_i32(value: i32) -> Option<TaskQueueKind>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a TaskQueueKind, or None if value is not a valid variant.

Source

impl TaskQueueKind

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.