#[repr(i32)]pub enum WorkflowExecutionStatus {
Unspecified = 0,
Running = 1,
Completed = 2,
Failed = 3,
Canceled = 4,
Terminated = 5,
ContinuedAsNew = 6,
TimedOut = 7,
Paused = 8,
}Expand description
(– api-linter: core::0216::synonyms=disabled aip.dev/not-precedent: There is WorkflowExecutionState already in another package. –)
Variants
Unspecified = 0
Running = 1
Value 1 is hardcoded in SQL persistence.
Completed = 2
Failed = 3
Canceled = 4
Terminated = 5
ContinuedAsNew = 6
TimedOut = 7
Paused = 8
Implementations
Sourceimpl WorkflowExecutionStatus
impl WorkflowExecutionStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of WorkflowExecutionStatus.
Sourcepub fn from_i32(value: i32) -> Option<WorkflowExecutionStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<WorkflowExecutionStatus>
Converts an i32 to a WorkflowExecutionStatus, or None if value is not a valid variant.
Sourceimpl WorkflowExecutionStatus
impl WorkflowExecutionStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.