pub struct MultiOperationExecutionFailure {
pub statuses: Vec<OperationStatus>,
}Fields
statuses: Vec<OperationStatus>One status for each requested operation from the failed MultiOperation. The failed
operation(s) have the same error details as if it was executed separately. All other operations have the
status code Aborted and MultiOperationExecutionAborted is added to the details field.