pub struct NamespaceInvalidStateFailure {
pub namespace: String,
pub state: i32,
pub allowed_states: Vec<i32>,
}Fields
namespace: Stringstate: i32Current state of the requested namespace.
allowed_states: Vec<i32>Allowed namespace states for requested operation. For example NAMESPACE_STATE_DELETED is forbidden for most operations but allowed for DescribeNamespace.
Implementations
Sourceimpl NamespaceInvalidStateFailure
impl NamespaceInvalidStateFailure
Sourcepub fn state(&self) -> NamespaceState
pub fn state(&self) -> NamespaceState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: NamespaceState)
pub fn set_state(&mut self, value: NamespaceState)
Sets state to the provided enum value.
Sourcepub fn allowed_states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<NamespaceState>>
pub fn allowed_states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<NamespaceState>>
Returns an iterator which yields the valid enum values contained in allowed_states.
Sourcepub fn push_allowed_states(&mut self, value: NamespaceState)
pub fn push_allowed_states(&mut self, value: NamespaceState)
Appends the provided enum value to allowed_states.