Failure

Struct Failure 

pub struct Failure {
    pub message: String,
    pub source: String,
    pub stack_trace: String,
    pub encoded_attributes: Option<Payload>,
    pub cause: Option<Box<Failure>>,
    pub failure_info: Option<FailureInfo>,
}

Fields

message: Stringsource: String

The source this Failure originated in, e.g. TypeScriptSDK / JavaSDK In some SDKs this is used to rehydrate the stack trace into an exception object.

stack_trace: Stringencoded_attributes: Option<Payload>

Alternative way to supply message and stack_trace and possibly other attributes, used for encryption of errors originating in user code which might contain sensitive information. The encoded_attributes Payload could represent any serializable object, e.g. JSON object or a Failure proto message.

SDK authors:

  • The SDK should provide a default encodeFailureAttributes and decodeFailureAttributes implementation that:

    • Uses a JSON object to represent { message, stack_trace }.
    • Overwrites the original message with “Encoded failure” to indicate that more information could be extracted.
    • Overwrites the original stack_trace with an empty string.
    • The resulting JSON object is converted to Payload using the default PayloadConverter and should be processed by the user-provided PayloadCodec
  • If there’s demand, we could allow overriding the default SDK implementation to encode other opaque Failure attributes. (– api-linter: core::0203::optional=disabled –)

cause: Option<Box<Failure>>failure_info: Option<FailureInfo>

Implementations

Source

impl Failure

pub fn is_timeout(&self) -> Option<TimeoutType>

pub fn application_failure(message: String, non_retryable: bool) -> Self

pub fn application_failure_from_error(ae: Error, non_retryable: bool) -> Self

pub fn timeout(timeout_type: TimeoutType) -> Self

pub fn maybe_application_failure(&self) -> Option<&ApplicationFailureInfo>

Extracts an ApplicationFailureInfo from a Failure instance if it exists

pub fn is_benign_application_failure(&self) -> bool