pub struct ActivityTaskCanceledEventAttributes {
pub details: Option<Payloads>,
pub latest_cancel_requested_event_id: i64,
pub scheduled_event_id: i64,
pub started_event_id: i64,
pub identity: String,
pub worker_version: Option<WorkerVersionStamp>,
}Fields
details: Option<Payloads>Additional information that the activity reported upon confirming cancellation
latest_cancel_requested_event_id: i64id of the most recent ACTIVITY_TASK_CANCEL_REQUESTED event which refers to the same
activity
scheduled_event_id: i64The id of the ACTIVITY_TASK_SCHEDULED event this cancel confirmation corresponds to
started_event_id: i64The id of the ACTIVITY_TASK_STARTED event this cancel confirmation corresponds to
identity: Stringid of the worker who canceled this activity
worker_version: Option<WorkerVersionStamp>👎Deprecated
Version info of the worker who processed this workflow task. Deprecated. This field should be cleaned up when versioning-2 API is removed. [cleanup-experimental-wv]