ActivityTaskStartedEventAttributes

Struct ActivityTaskStartedEventAttributes 

pub struct ActivityTaskStartedEventAttributes {
    pub scheduled_event_id: i64,
    pub identity: String,
    pub request_id: String,
    pub attempt: i32,
    pub last_failure: Option<Failure>,
    pub worker_version: Option<WorkerVersionStamp>,
    pub build_id_redirect_counter: i64,
}

Fields

scheduled_event_id: i64

The id of the ACTIVITY_TASK_SCHEDULED event this task corresponds to

identity: String

id of the worker that picked up this task

request_id: String

This field is populated from the RecordActivityTaskStartedRequest. Matching service would set the request_id on the RecordActivityTaskStartedRequest to a new UUID. This is useful in case a RecordActivityTaskStarted call succeed but matching doesn’t get that response, so matching could retry and history service would return success if the request_id matches. In that case, matching will continue to deliver the task to worker. Without this field, history service would return AlreadyStarted error, and matching would drop the task.

attempt: i32

Starting at 1, the number of times this task has been attempted

last_failure: Option<Failure>

Will be set to the most recent failure details, if this task has previously failed and then been retried.

worker_version: Option<WorkerVersionStamp>
👎Deprecated

Version info of the worker to whom this task was dispatched. Deprecated. This field should be cleaned up when versioning-2 API is removed. [cleanup-experimental-wv]

build_id_redirect_counter: i64
👎Deprecated

Used by server internally to properly reapply build ID redirects to an execution when rebuilding it from events. Deprecated. This field should be cleaned up when versioning-2 API is removed. [cleanup-experimental-wv]