pub struct ActivityTaskTimedOutEventAttributes {
pub failure: Option<Failure>,
pub scheduled_event_id: i64,
pub started_event_id: i64,
pub retry_state: i32,
}Fields
failure: Option<Failure>If this activity had failed, was retried, and then timed out, that failure is stored as the
cause in here.
scheduled_event_id: i64The id of the ACTIVITY_TASK_SCHEDULED event this timeout corresponds to
started_event_id: i64The id of the ACTIVITY_TASK_STARTED event this timeout corresponds to
retry_state: i32Implementations
Sourceimpl ActivityTaskTimedOutEventAttributes
impl ActivityTaskTimedOutEventAttributes
Sourcepub fn retry_state(&self) -> RetryState
pub fn retry_state(&self) -> RetryState
Returns the enum value of retry_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_retry_state(&mut self, value: RetryState)
pub fn set_retry_state(&mut self, value: RetryState)
Sets retry_state to the provided enum value.