pub struct NamespaceConfig {
pub workflow_execution_retention_ttl: Option<Duration>,
pub bad_binaries: Option<BadBinaries>,
pub history_archival_state: i32,
pub history_archival_uri: String,
pub visibility_archival_state: i32,
pub visibility_archival_uri: String,
pub custom_search_attribute_aliases: HashMap<String, String>,
}Fields
workflow_execution_retention_ttl: Option<Duration>bad_binaries: Option<BadBinaries>history_archival_state: i32If unspecified (ARCHIVAL_STATE_UNSPECIFIED) then default server configuration is used.
history_archival_uri: Stringvisibility_archival_state: i32If unspecified (ARCHIVAL_STATE_UNSPECIFIED) then default server configuration is used.
visibility_archival_uri: Stringcustom_search_attribute_aliases: HashMap<String, String>Map from field name to alias.
Implementations
Sourceimpl NamespaceConfig
impl NamespaceConfig
Sourcepub fn history_archival_state(&self) -> ArchivalState
pub fn history_archival_state(&self) -> ArchivalState
Returns the enum value of history_archival_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_history_archival_state(&mut self, value: ArchivalState)
pub fn set_history_archival_state(&mut self, value: ArchivalState)
Sets history_archival_state to the provided enum value.
Sourcepub fn visibility_archival_state(&self) -> ArchivalState
pub fn visibility_archival_state(&self) -> ArchivalState
Returns the enum value of visibility_archival_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility_archival_state(&mut self, value: ArchivalState)
pub fn set_visibility_archival_state(&mut self, value: ArchivalState)
Sets visibility_archival_state to the provided enum value.