pub struct HandlerError {
pub error_type: String,
pub failure: Option<Failure>,
pub retry_behavior: i32,
}Fields
error_type: Stringfailure: Option<Failure>retry_behavior: i32Retry behavior, defaults to the retry behavior of the error type as defined in the spec.
Implementations
Sourceimpl HandlerError
impl HandlerError
Sourcepub fn retry_behavior(&self) -> NexusHandlerErrorRetryBehavior
pub fn retry_behavior(&self) -> NexusHandlerErrorRetryBehavior
Returns the enum value of retry_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_retry_behavior(&mut self, value: NexusHandlerErrorRetryBehavior)
pub fn set_retry_behavior(&mut self, value: NexusHandlerErrorRetryBehavior)
Sets retry_behavior to the provided enum value.