pub struct AddOrUpdateRemoteClusterRequest {
pub frontend_address: String,
pub enable_remote_cluster_connection: bool,
pub frontend_http_address: String,
pub enable_replication: bool,
}Fields
frontend_address: StringFrontend Address is a cross cluster accessible address for gRPC traffic. This field is required.
enable_remote_cluster_connection: boolFlag to enable / disable the cross cluster connection.
frontend_http_address: StringFrontend HTTP Address is a cross cluster accessible address for HTTP traffic. This field is optional. If not provided on update, the existing HTTP address will be removed.
enable_replication: boolControls whether replication streams are active.