pub struct AddSearchAttributesRequest {
pub search_attributes: HashMap<String, i32>,
pub namespace: String,
}Fields
search_attributes: HashMap<String, i32>Mapping between search attribute name and its IndexedValueType.
namespace: StringImplementations
Sourceimpl AddSearchAttributesRequest
impl AddSearchAttributesRequest
Sourcepub fn get_search_attributes(&self, key: &str) -> Option<IndexedValueType>
pub fn get_search_attributes(&self, key: &str) -> Option<IndexedValueType>
Returns the enum value for the corresponding key in search_attributes, or None if the entry does not exist or it is not a valid enum value.
Sourcepub fn insert_search_attributes(
&mut self,
key: String,
value: IndexedValueType,
) -> Option<IndexedValueType>
pub fn insert_search_attributes( &mut self, key: String, value: IndexedValueType, ) -> Option<IndexedValueType>
Inserts a key value pair into search_attributes.