pub enum SequencingId {
EventId(i64),
CommandIndex(i64),
}Expand description
The event ID or command ID after which this message can be delivered. The effects of history up to and including this event ID should be visible to the code that handles this message. Omit to opt out of sequencing.
Variants
Implementations
Sourceimpl SequencingId
impl SequencingId
Sourcepub fn merge(
field: &mut Option<SequencingId>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<SequencingId>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.