pub struct QueryRejected {
pub status: i32,
}Fields
status: i32Implementations
Sourceimpl QueryRejected
impl QueryRejected
Sourcepub fn status(&self) -> WorkflowExecutionStatus
pub fn status(&self) -> WorkflowExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: WorkflowExecutionStatus)
pub fn set_status(&mut self, value: WorkflowExecutionStatus)
Sets status to the provided enum value.