pub struct WorkflowQuery {
pub query_type: String,
pub query_args: Option<Payloads>,
pub header: Option<Header>,
}Expand description
Fields
query_type: StringThe workflow-author-defined identifier of the query. Typically a function name.
query_args: Option<Payloads>Serialized arguments that will be provided to the query handler.
header: Option<Header>Headers that were passed by the caller of the query and copied by temporal server into the workflow task.