pub struct NamespaceReplicationConfig {
pub active_cluster_name: String,
pub clusters: Vec<ClusterReplicationConfig>,
pub state: i32,
}Fields
active_cluster_name: Stringclusters: Vec<ClusterReplicationConfig>state: i32Implementations
Sourceimpl NamespaceReplicationConfig
impl NamespaceReplicationConfig
Sourcepub fn state(&self) -> ReplicationState
pub fn state(&self) -> ReplicationState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ReplicationState)
pub fn set_state(&mut self, value: ReplicationState)
Sets state to the provided enum value.