pub struct WorkflowRule {
pub create_time: Option<Timestamp>,
pub spec: Option<WorkflowRuleSpec>,
pub created_by_identity: String,
pub description: String,
}Expand description
WorkflowRule describes a rule that can be applied to any workflow in this namespace.
Fields
create_time: Option<Timestamp>Rule creation time.
spec: Option<WorkflowRuleSpec>Rule specification
created_by_identity: StringIdentity of the actor that created the rule (– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: It is better reflect the intent this way, we will also have updated_by. –) (– api-linter: core::0142::time-field-names=disabled aip.dev/not-precedent: Same as above. All other options sounds clumsy –)
description: StringRule description.