pub struct BackfillRequest {
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub overlap_policy: i32,
}Fields
start_time: Option<Timestamp>Time range to evaluate schedule in. Currently, this time range is exclusive on start_time and inclusive on end_time. (This is admittedly counterintuitive and it may change in the future, so to be safe, use a start time strictly before a scheduled time.) Also note that an action nominally scheduled in the interval but with jitter that pushes it after end_time will not be included.
end_time: Option<Timestamp>overlap_policy: i32If set, override overlap policy for this request.
Implementations
Sourceimpl BackfillRequest
impl BackfillRequest
Sourcepub fn overlap_policy(&self) -> ScheduleOverlapPolicy
pub fn overlap_policy(&self) -> ScheduleOverlapPolicy
Returns the enum value of overlap_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_overlap_policy(&mut self, value: ScheduleOverlapPolicy)
pub fn set_overlap_policy(&mut self, value: ScheduleOverlapPolicy)
Sets overlap_policy to the provided enum value.