pub struct TriggerImmediatelyRequest {
pub overlap_policy: i32,
pub scheduled_time: Option<Timestamp>,
}Fields
overlap_policy: i32If set, override overlap policy for this one request.
scheduled_time: Option<Timestamp>Timestamp used for the identity of the target workflow. If not set the default value is the current time.
Implementations
Sourceimpl TriggerImmediatelyRequest
impl TriggerImmediatelyRequest
Sourcepub fn overlap_policy(&self) -> ScheduleOverlapPolicy
pub fn overlap_policy(&self) -> ScheduleOverlapPolicy
Returns the enum value of overlap_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_overlap_policy(&mut self, value: ScheduleOverlapPolicy)
pub fn set_overlap_policy(&mut self, value: ScheduleOverlapPolicy)
Sets overlap_policy to the provided enum value.