pub struct WorkflowInteractionDefinition {
pub name: String,
pub description: String,
}Expand description
(– api-linter: core::0123::resource-annotation=disabled
aip.dev/not-precedent: The name field is optional. –)
(– api-linter: core::0203::optional=disabled –)
Fields
name: StringAn optional name for the handler. If missing, it represents a dynamic handler that processes any interactions not handled by others. There is at most one dynamic handler per workflow and interaction kind.
description: StringAn optional interaction description provided by the application. By convention, external tools may interpret its first part, i.e., ending with a line break, as a summary of the description.