pub struct WorkflowMetadata {
pub definition: Option<WorkflowDefinition>,
pub current_details: String,
}Expand description
The name of the query to retrieve this information is __temporal_workflow_metadata.
Fields
definition: Option<WorkflowDefinition>Metadata provided at declaration or creation time.
current_details: StringCurrent long-form details of the workflow’s state. This is used by user interfaces to show long-form text. This text may be formatted by the user interface.