Module v1

Module v1 

Modules

build_id_assignment_rule
Nested message and enum types in BuildIdAssignmentRule.

Structs

BuildIdAssignmentRule
Assignment rules are applied to new Workflow and Activity executions at schedule time to assign them to a Build ID.
BuildIdReachability
Reachability of tasks for a worker by build id, in one or more task queues.
CompatibleBuildIdRedirectRule
These rules apply to tasks assigned to a particular Build ID (source_build_id) to redirect them to another compatible Build ID (target_build_id).
CompatibleVersionSet
Used by the worker versioning APIs, represents an unordered set of one or more versions which are considered to be compatible with each other. Currently the versions are always worker build IDs.
ConfigMetadata
PollerInfo
PollerScalingDecision
Attached to task responses to give hints to the SDK about how it may adjust its number of pollers.
RampByPercentage
RateLimit
RateLimitConfig
StickyExecutionAttributes
TaskIdBlock
TaskQueue
See https://docs.temporal.io/docs/concepts/task-queues/
TaskQueueConfig
TaskQueueMetadata
Only applies to activity task queues
TaskQueuePartitionMetadata
TaskQueueReachability
Reachability of tasks for a worker on a single task queue.
TaskQueueStats
TaskQueueStats contains statistics about task queue backlog and activity.
TaskQueueStatus
Deprecated. Use InternalTaskQueueStatus. This is kept until DescribeTaskQueue supports legacy behavior.
TaskQueueTypeInfo
TaskQueueVersionInfo
TaskQueueVersionSelection
Used for specifying versions the caller is interested in.
TaskQueueVersioningInfo
Experimental. Worker Deployments are experimental and might significantly change in the future.
TimestampedBuildIdAssignmentRule
TimestampedCompatibleBuildIdRedirectRule