pub struct CompatibleVersionSet {
pub build_ids: Vec<String>,
}Expand description
Used by the worker versioning APIs, represents an unordered set of one or more versions which are considered to be compatible with each other. Currently the versions are always worker build IDs.
Fields
build_ids: Vec<String>All the compatible versions, unordered, except for the last element, which is considered the set “default”.