pub struct PollerScalingDecision {
pub poll_request_delta_suggestion: i32,
}Expand description
Attached to task responses to give hints to the SDK about how it may adjust its number of pollers.
Fields
poll_request_delta_suggestion: i32How many poll requests to suggest should be added or removed, if any. As of now, server only scales up or down by 1. However, SDKs should allow for other values (while staying within defined min/max).
The SDK is free to ignore this suggestion, EX: making more polls would not make sense because all slots are already occupied.