pub struct TaskQueue {
pub name: String,
pub kind: i32,
pub normal_name: String,
}Expand description
Fields
name: Stringkind: i32Default: TASK_QUEUE_KIND_NORMAL.
normal_name: StringIff kind == TASK_QUEUE_KIND_STICKY, then this field contains the name of the normal task queue that the sticky worker is running on.
Implementations
Sourceimpl TaskQueue
impl TaskQueue
Sourcepub fn kind(&self) -> TaskQueueKind
pub fn kind(&self) -> TaskQueueKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: TaskQueueKind)
pub fn set_kind(&mut self, value: TaskQueueKind)
Sets kind to the provided enum value.