pub struct TaskQueueConfig {
pub queue_rate_limit: Option<RateLimitConfig>,
pub fairness_keys_rate_limit_default: Option<RateLimitConfig>,
pub fairness_weight_overrides: HashMap<String, f32>,
}Fields
queue_rate_limit: Option<RateLimitConfig>Unless modified, this is the system-defined rate limit.
fairness_keys_rate_limit_default: Option<RateLimitConfig>If set, each individual fairness key will be limited to this rate, scaled by the weight of the fairness key.
fairness_weight_overrides: HashMap<String, f32>If set, overrides the fairness weights for the corresponding fairness keys.