pub struct TaskQueueReachability {
pub task_queue: String,
pub reachability: Vec<i32>,
}Expand description
Reachability of tasks for a worker on a single task queue.
Fields
task_queue: Stringreachability: Vec<i32>Task reachability for a worker in a single task queue. See the TaskReachability docstring for information about each enum variant. If reachability is empty, this worker is considered unreachable in this task queue.
Implementations
Sourceimpl TaskQueueReachability
impl TaskQueueReachability
Sourcepub fn reachability(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TaskReachability>>
pub fn reachability( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TaskReachability>>
Returns an iterator which yields the valid enum values contained in reachability.
Sourcepub fn push_reachability(&mut self, value: TaskReachability)
pub fn push_reachability(&mut self, value: TaskReachability)
Appends the provided enum value to reachability.