pub struct TaskQueueVersionInfo {
pub types_info: HashMap<i32, TaskQueueTypeInfo>,
pub task_reachability: i32,
}Fields
types_info: HashMap<i32, TaskQueueTypeInfo>Task Queue info per Task Type. Key is the numerical value of the temporal.api.enums.v1.TaskQueueType enum.
task_reachability: i32Task Reachability is eventually consistent; there may be a delay until it converges to the most accurate value but it is designed in a way to take the more conservative side until it converges. For example REACHABLE is more conservative than CLOSED_WORKFLOWS_ONLY.
Note: future activities who inherit their workflow’s Build ID but not its Task Queue will not be accounted for reachability as server cannot know if they’ll happen as they do not use assignment rules of their Task Queue. Same goes for Child Workflows or Continue-As-New Workflows who inherit the parent/previous workflow’s Build ID but not its Task Queue. In those cases, make sure to query reachability for the parent/previous workflow’s Task Queue as well.
Implementations
Sourceimpl TaskQueueVersionInfo
impl TaskQueueVersionInfo
Sourcepub fn task_reachability(&self) -> BuildIdTaskReachability
pub fn task_reachability(&self) -> BuildIdTaskReachability
Returns the enum value of task_reachability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_task_reachability(&mut self, value: BuildIdTaskReachability)
pub fn set_task_reachability(&mut self, value: BuildIdTaskReachability)
Sets task_reachability to the provided enum value.