TaskQueueVersionSelection

Struct TaskQueueVersionSelection 

pub struct TaskQueueVersionSelection {
    pub build_ids: Vec<String>,
    pub unversioned: bool,
    pub all_active: bool,
}
Used for specifying versions the caller is interested in.

Fields

build_ids: Vec<String>

Include specific Build IDs.

unversioned: bool

Include the unversioned queue.

all_active: bool

Include all active versions. A version is considered active if, in the last few minutes, it has had new tasks or polls, or it has been the subject of certain task queue API calls.