pub struct WaitPolicy {
pub lifecycle_stage: i32,
}Expand description
Specifies client’s intent to wait for Update results.
Fields
lifecycle_stage: i32Indicates the Update lifecycle stage that the Update must reach before API call is returned. NOTE: This field works together with API call timeout which is limited by server timeout (maximum wait time). If server timeout is expired before user specified timeout, API call returns even if specified stage is not reached.
Implementations
Sourceimpl WaitPolicy
impl WaitPolicy
Sourcepub fn lifecycle_stage(&self) -> UpdateWorkflowExecutionLifecycleStage
pub fn lifecycle_stage(&self) -> UpdateWorkflowExecutionLifecycleStage
Returns the enum value of lifecycle_stage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_lifecycle_stage(
&mut self,
value: UpdateWorkflowExecutionLifecycleStage,
)
pub fn set_lifecycle_stage( &mut self, value: UpdateWorkflowExecutionLifecycleStage, )
Sets lifecycle_stage to the provided enum value.