CallbackInfo

Struct CallbackInfo 

pub struct CallbackInfo {
    pub callback: Option<Callback>,
    pub trigger: Option<Trigger>,
    pub registration_time: Option<Timestamp>,
    pub state: i32,
    pub attempt: i32,
    pub last_attempt_complete_time: Option<Timestamp>,
    pub last_attempt_failure: Option<Failure>,
    pub next_attempt_schedule_time: Option<Timestamp>,
    pub blocked_reason: String,
}
CallbackInfo contains the state of an attached workflow callback.

Fields

callback: Option<Callback>

Information on how this callback should be invoked (e.g. its URL and type).

trigger: Option<Trigger>

Trigger for this callback.

registration_time: Option<Timestamp>

The time when the callback was registered.

state: i32attempt: i32

The number of attempts made to deliver the callback. This number represents a minimum bound since the attempt is incremented after the callback request completes.

last_attempt_complete_time: Option<Timestamp>

The time when the last attempt completed.

last_attempt_failure: Option<Failure>

The last attempt’s failure, if any.

next_attempt_schedule_time: Option<Timestamp>

The time when the next attempt is scheduled.

blocked_reason: String

If the state is BLOCKED, blocked reason provides additional information.

Implementations

Source

impl CallbackInfo

pub fn state(&self) -> CallbackState

Returns the enum value of state, or the default if the field is set to an invalid enum value.

pub fn set_state(&mut self, value: CallbackState)

Sets state to the provided enum value.