RequestIdInfo

Struct RequestIdInfo 

pub struct RequestIdInfo {
    pub event_type: i32,
    pub event_id: i64,
    pub buffered: bool,
}
RequestIdInfo contains details of a request ID.

Fields

event_type: i32

The event type of the history event generated by the request.

event_id: i64

The event id of the history event generated by the request. It’s possible the event ID is not known (unflushed buffered event). In this case, the value will be zero or a negative value, representing an invalid ID.

buffered: bool

Indicate if the request is still buffered. If so, the event ID is not known and its value will be an invalid event ID.

Implementations

Source

impl RequestIdInfo

pub fn event_type(&self) -> EventType

Returns the enum value of event_type, or the default if the field is set to an invalid enum value.

pub fn set_event_type(&mut self, value: EventType)

Sets event_type to the provided enum value.