pub struct VersioningOverride {
pub behavior: i32,
pub deployment: Option<Deployment>,
pub pinned_version: String,
pub override: Option<Override>,
}Expand description
Used to override the versioning behavior (and pinned deployment version, if applicable) of a
specific workflow execution. If set, this override takes precedence over worker-sent values.
See WorkflowExecutionInfo.VersioningInfo for more information.
To remove the override, call UpdateWorkflowExecutionOptions with a null
VersioningOverride, and use the update_mask to indicate that it should be mutated.
Pinned behavior overrides are automatically inherited by child workflows, workflow retries, continue-as-new workflows, and cron workflows.
Fields
behavior: i32Required.
Deprecated. Use override.
deployment: Option<Deployment>Required if behavior is PINNED. Must be null if behavior is AUTO_UPGRADE.
Identifies the worker deployment to pin the workflow to.
Deprecated. Use override.pinned.version.
pinned_version: StringRequired if behavior is PINNED. Must be absent if behavior is not PINNED.
Identifies the worker deployment version to pin the workflow to, in the format
“<deployment_name>.<build_id>”.
Deprecated. Use override.pinned.version.
override: Option<Override>Indicates whether to override the workflow to be AutoUpgrade or Pinned.
Implementations
Sourceimpl VersioningOverride
impl VersioningOverride
Sourcepub fn behavior(&self) -> VersioningBehavior
pub fn behavior(&self) -> VersioningBehavior
Returns the enum value of behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_behavior(&mut self, value: VersioningBehavior)
pub fn set_behavior(&mut self, value: VersioningBehavior)
Sets behavior to the provided enum value.