CountActivityExecutionsResponse

Struct CountActivityExecutionsResponse 

pub struct CountActivityExecutionsResponse {
    pub count: i64,
    pub groups: Vec<AggregationGroup>,
}

Fields

count: i64

If query is not grouping by any field, the count is an approximate number of activities that match the query. If query is grouping by a field, the count is simply the sum of the counts of the groups returned in the response. This number can be smaller than the total number of activities matching the query.

groups: Vec<AggregationGroup>

Contains the groups if the request is grouping by a field. The list might not be complete, and the counts of each group is approximate.