CreateScheduleRequest

Struct CreateScheduleRequest 

pub struct CreateScheduleRequest {
    pub namespace: String,
    pub schedule_id: String,
    pub schedule: Option<Schedule>,
    pub initial_patch: Option<SchedulePatch>,
    pub identity: String,
    pub request_id: String,
    pub memo: Option<Memo>,
    pub search_attributes: Option<SearchAttributes>,
}
(– api-linter: core::0203::optional=disabled aip.dev/not-precedent: field_behavior annotation not available in our gogo fork –)

Fields

namespace: String

The namespace the schedule should be created in.

schedule_id: String

The id of the new schedule.

schedule: Option<Schedule>

The schedule spec, policies, action, and initial state.

initial_patch: Option<SchedulePatch>

Optional initial patch (e.g. to run the action once immediately).

identity: String

The identity of the client who initiated this request.

request_id: String

A unique identifier for this create request for idempotence. Typically UUIDv4.

memo: Option<Memo>

Memo and search attributes to attach to the schedule itself.

search_attributes: Option<SearchAttributes>