pub struct DescribeActivityExecutionResponse {
pub run_id: String,
pub info: Option<ActivityExecutionInfo>,
pub input: Option<Payloads>,
pub outcome: Option<ActivityExecutionOutcome>,
pub long_poll_token: Vec<u8>,
}Fields
run_id: StringThe run ID of the activity, useful when run_id was not specified in the request.
info: Option<ActivityExecutionInfo>Information about the activity execution.
input: Option<Payloads>Serialized activity input, passed as arguments to the activity function. Only set if include_input was true in the request.
outcome: Option<ActivityExecutionOutcome>Only set if the activity is completed and include_outcome was true in the request.
long_poll_token: Vec<u8>Token for follow-on long-poll requests. Absent only if the activity is complete.