pub struct DescribeNamespaceResponse {
pub namespace_info: Option<NamespaceInfo>,
pub config: Option<NamespaceConfig>,
pub replication_config: Option<NamespaceReplicationConfig>,
pub failover_version: i64,
pub is_global_namespace: bool,
pub failover_history: Vec<FailoverStatus>,
}Fields
namespace_info: Option<NamespaceInfo>config: Option<NamespaceConfig>replication_config: Option<NamespaceReplicationConfig>failover_version: i64is_global_namespace: boolfailover_history: Vec<FailoverStatus>Contains the historical state of failover_versions for the cluster, truncated to contain only the last N states to ensure that the list does not grow unbounded.