DescribeTaskQueueRequest

Struct DescribeTaskQueueRequest 

pub struct DescribeTaskQueueRequest {
    pub namespace: String,
    pub task_queue: Option<TaskQueue>,
    pub task_queue_type: i32,
    pub report_stats: bool,
    pub report_config: bool,
    pub include_task_queue_status: bool,
    pub api_mode: i32,
    pub versions: Option<TaskQueueVersionSelection>,
    pub task_queue_types: Vec<i32>,
    pub report_pollers: bool,
    pub report_task_reachability: bool,
}
(– api-linter: core::0203::optional=disabled aip.dev/not-precedent: field_behavior annotation not available in our gogo fork –)

Fields

namespace: Stringtask_queue: Option<TaskQueue>

Sticky queues are not supported in deprecated ENHANCED mode.

task_queue_type: i32

If unspecified (TASK_QUEUE_TYPE_UNSPECIFIED), then default value (TASK_QUEUE_TYPE_WORKFLOW) will be used. Only supported in default mode (use task_queue_types in ENHANCED mode instead).

report_stats: bool

Report stats for the requested task queue type(s).

report_config: bool

Report Task Queue Config

include_task_queue_status: bool
👎Deprecated

Deprecated, use report_stats instead. If true, the task queue status will be included in the response.

api_mode: i32
👎Deprecated

Deprecated. ENHANCED mode is also being deprecated. Select the API mode to use for this request: DEFAULT mode (if unset) or ENHANCED mode. Consult the documentation for each field to understand which mode it is supported in.

versions: Option<TaskQueueVersionSelection>
👎Deprecated

Deprecated (as part of the ENHANCED mode deprecation). Optional. If not provided, the result for the default Build ID will be returned. The default Build ID is the one mentioned in the first unconditional Assignment Rule. If there is no default Build ID, the result for the unversioned queue will be returned. (– api-linter: core::0140::prepositions –)

task_queue_types: Vec<i32>
👎Deprecated

Deprecated (as part of the ENHANCED mode deprecation). Task queue types to report info about. If not specified, all types are considered.

report_pollers: bool
👎Deprecated

Deprecated (as part of the ENHANCED mode deprecation). Report list of pollers for requested task queue types and versions.

report_task_reachability: bool
👎Deprecated

Deprecated (as part of the ENHANCED mode deprecation). Report task reachability for the requested versions and all task types (task reachability is not reported per task type).

Implementations

Source

impl DescribeTaskQueueRequest

pub fn task_queue_type(&self) -> TaskQueueType

Returns the enum value of task_queue_type, or the default if the field is set to an invalid enum value.

pub fn set_task_queue_type(&mut self, value: TaskQueueType)

Sets task_queue_type to the provided enum value.

pub fn api_mode(&self) -> DescribeTaskQueueMode

Returns the enum value of api_mode, or the default if the field is set to an invalid enum value.

pub fn set_api_mode(&mut self, value: DescribeTaskQueueMode)

Sets api_mode to the provided enum value.

pub fn task_queue_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TaskQueueType>>

Returns an iterator which yields the valid enum values contained in task_queue_types.

pub fn push_task_queue_types(&mut self, value: TaskQueueType)

Appends the provided enum value to task_queue_types.