pub struct DescribeTaskQueueResponse {
pub pollers: Vec<PollerInfo>,
pub stats: Option<TaskQueueStats>,
pub stats_by_priority_key: HashMap<i32, TaskQueueStats>,
pub versioning_info: Option<TaskQueueVersioningInfo>,
pub config: Option<TaskQueueConfig>,
pub effective_rate_limit: Option<EffectiveRateLimit>,
pub task_queue_status: Option<TaskQueueStatus>,
pub versions_info: HashMap<String, TaskQueueVersionInfo>,
}Fields
pollers: Vec<PollerInfo>stats: Option<TaskQueueStats>Statistics for the task queue.
Only set if report_stats is set on the request.
stats_by_priority_key: HashMap<i32, TaskQueueStats>Task queue stats breakdown by priority key. Only contains actively used priority keys.
Only set if report_stats is set on the request.
(– api-linter: core::0140::prepositions=disabled
aip.dev/not-precedent: “by” is used to clarify the keys and values. –)
versioning_info: Option<TaskQueueVersioningInfo>Specifies which Worker Deployment Version(s) Server routes this Task Queue’s tasks to. When not present, it means the tasks are routed to Unversioned workers (workers with UNVERSIONED or unspecified WorkerVersioningMode.) Task Queue Versioning info is updated indirectly by calling SetWorkerDeploymentCurrentVersion and SetWorkerDeploymentRampingVersion on Worker Deployments. Note: This information is not relevant to Pinned workflow executions and their activities as they are always routed to their Pinned Deployment Version. However, new workflow executions are typically not Pinned until they complete their first task (unless they are started with a Pinned VersioningOverride or are Child Workflows of a Pinned parent).
config: Option<TaskQueueConfig>Only populated if report_task_queue_config is set to true.
effective_rate_limit: Option<EffectiveRateLimit>task_queue_status: Option<TaskQueueStatus>Deprecated.
Status of the task queue. Only populated when include_task_queue_status is set to true in the request.
versions_info: HashMap<String, TaskQueueVersionInfo>Deprecated. Only returned in ENHANCED mode. This map contains Task Queue information for each Build ID. Empty string as key value means unversioned.