pub struct ExecuteMultiOperationRequest {
pub namespace: String,
pub operations: Vec<Operation>,
}Fields
namespace: Stringoperations: Vec<Operation>List of operations to execute within a single workflow.
Preconditions:
- The list of operations must not be empty.
- The workflow ids must match across operations.
- The only valid list of operations at this time is [StartWorkflow, UpdateWorkflow], in this order.
Note that additional operation-specific restrictions have to be considered.