pub struct PollActivityTaskQueueRequest {
pub namespace: String,
pub task_queue: Option<TaskQueue>,
pub identity: String,
pub worker_instance_key: String,
pub task_queue_metadata: Option<TaskQueueMetadata>,
pub worker_version_capabilities: Option<WorkerVersionCapabilities>,
pub deployment_options: Option<WorkerDeploymentOptions>,
}Fields
namespace: Stringtask_queue: Option<TaskQueue>identity: StringThe identity of the worker/client
worker_instance_key: StringA unique key for this worker instance, used for tracking worker lifecycle. This is guaranteed to be unique, whereas identity is not guaranteed to be unique.
task_queue_metadata: Option<TaskQueueMetadata>worker_version_capabilities: Option<WorkerVersionCapabilities>👎Deprecated
Information about this worker’s build identifier and if it is choosing to use the versioning
feature. See the WorkerVersionCapabilities docstring for more.
Deprecated. Replaced by deployment_options.
deployment_options: Option<WorkerDeploymentOptions>Worker deployment options that user has set in the worker.