pub struct PollNexusTaskQueueRequest {
pub namespace: String,
pub identity: String,
pub worker_instance_key: String,
pub task_queue: Option<TaskQueue>,
pub worker_version_capabilities: Option<WorkerVersionCapabilities>,
pub deployment_options: Option<WorkerDeploymentOptions>,
pub worker_heartbeat: Vec<WorkerHeartbeat>,
}Fields
namespace: Stringidentity: StringThe identity of the client who initiated this request.
worker_instance_key: StringA unique key for this worker instance, used for tracking worker lifecycle. This is guaranteed to be unique, whereas identity is not guaranteed to be unique.
task_queue: Option<TaskQueue>worker_version_capabilities: Option<WorkerVersionCapabilities>👎Deprecated
Information about this worker’s build identifier and if it is choosing to use the versioning
feature. See the WorkerVersionCapabilities docstring for more.
Deprecated. Replaced by deployment_options.
deployment_options: Option<WorkerDeploymentOptions>Worker deployment options that user has set in the worker.
worker_heartbeat: Vec<WorkerHeartbeat>Worker info to be sent to the server.