pub struct PollNexusTaskQueueResponse {
pub task_token: Vec<u8>,
pub request: Option<Request>,
pub poller_scaling_decision: Option<PollerScalingDecision>,
}Fields
task_token: Vec<u8>An opaque unique identifier for this task for correlating a completion request the embedded request.
request: Option<Request>Embedded request as translated from the incoming frontend request.
poller_scaling_decision: Option<PollerScalingDecision>Server-advised information the SDK may use to adjust its poller count.
Implementations
Sourceimpl PollNexusTaskQueueResponse
impl PollNexusTaskQueueResponse
pub fn sched_to_start(&self) -> Option<Duration>