pub struct RequestCancelActivityExecutionRequest {
pub namespace: String,
pub activity_id: String,
pub run_id: String,
pub identity: String,
pub request_id: String,
pub reason: String,
}Fields
namespace: Stringactivity_id: Stringrun_id: StringActivity run ID, targets the latest run if run_id is empty.
identity: StringThe identity of the worker/client.
request_id: StringUsed to de-dupe cancellation requests.
reason: StringReason for requesting the cancellation, recorded and available via the PollActivityExecution API. Not propagated to a worker if an activity attempt is currently running.