ResetActivityRequest

Struct ResetActivityRequest 

pub struct ResetActivityRequest {
    pub namespace: String,
    pub execution: Option<WorkflowExecution>,
    pub identity: String,
    pub reset_heartbeat: bool,
    pub keep_paused: bool,
    pub jitter: Option<Duration>,
    pub restore_original_options: bool,
    pub activity: Option<Activity>,
}
NOTE: keep in sync with temporal.api.batch.v1.BatchOperationResetActivities

Fields

namespace: String

Namespace of the workflow which scheduled this activity.

execution: Option<WorkflowExecution>

Execution info of the workflow which scheduled this activity

identity: String

The identity of the client who initiated this request.

reset_heartbeat: bool

Indicates that activity should reset heartbeat details. This flag will be applied only to the new instance of the activity.

keep_paused: bool

If activity is paused, it will remain paused after reset

jitter: Option<Duration>

If set, and activity is in backoff, the activity will start at a random time within the specified jitter duration. (unless it is paused and keep_paused is set)

restore_original_options: bool

If set, the activity options will be restored to the defaults. Default options are then options activity was created with. They are part of the first SCHEDULE event.

activity: Option<Activity>

either activity id, activity type or update_all must be provided