pub struct RespondActivityTaskCanceledByIdRequest {
pub namespace: String,
pub workflow_id: String,
pub run_id: String,
pub activity_id: String,
pub details: Option<Payloads>,
pub identity: String,
pub deployment_options: Option<WorkerDeploymentOptions>,
}Fields
namespace: StringNamespace of the workflow which scheduled this activity
workflow_id: StringId of the workflow which scheduled this activity, leave empty to target a standalone activity
run_id: StringFor a workflow activity - the run ID of the workflow which scheduled this activity. For a standalone activity - the run ID of the activity.
activity_id: StringId of the activity to confirm is cancelled
details: Option<Payloads>Serialized additional information to attach to the cancellation
identity: StringThe identity of the worker/client
deployment_options: Option<WorkerDeploymentOptions>Worker deployment options that user has set in the worker.