pub struct SetCurrentDeploymentRequest {
pub namespace: String,
pub deployment: Option<Deployment>,
pub identity: String,
pub update_metadata: Option<UpdateDeploymentMetadata>,
}Expand description
[cleanup-wv-pre-release] Pre-release deployment APIs, clean up later
Fields
namespace: Stringdeployment: Option<Deployment>identity: StringOptional. The identity of the client who initiated this request.
update_metadata: Option<UpdateDeploymentMetadata>Optional. Use to add or remove user-defined metadata entries. Metadata entries are exposed when describing a deployment. It is a good place for information such as operator name, links to internal deployment pipelines, etc.