StartActivityExecutionRequest

Struct StartActivityExecutionRequest 

pub struct StartActivityExecutionRequest {
Show 18 fields pub namespace: String, pub identity: String, pub request_id: String, pub activity_id: String, pub activity_type: Option<ActivityType>, pub task_queue: Option<TaskQueue>, pub schedule_to_close_timeout: Option<Duration>, pub schedule_to_start_timeout: Option<Duration>, pub start_to_close_timeout: Option<Duration>, pub heartbeat_timeout: Option<Duration>, pub retry_policy: Option<RetryPolicy>, pub input: Option<Payloads>, pub id_reuse_policy: i32, pub id_conflict_policy: i32, pub search_attributes: Option<SearchAttributes>, pub header: Option<Header>, pub user_metadata: Option<UserMetadata>, pub priority: Option<Priority>,
}

Fields

namespace: Stringidentity: String

The identity of the client who initiated this request

request_id: String

A unique identifier for this start request. Typically UUIDv4.

activity_id: String

Identifier for this activity. Required. This identifier should be meaningful in the user’s own system. It must be unique among activities in the same namespace, subject to the rules imposed by id_reuse_policy and id_conflict_policy.

activity_type: Option<ActivityType>

The type of the activity, a string that corresponds to a registered activity on a worker.

task_queue: Option<TaskQueue>

Task queue to schedule this activity on.

schedule_to_close_timeout: Option<Duration>

Indicates how long the caller is willing to wait for an activity completion. Limits how long retries will be attempted. Either this or start_to_close_timeout must be specified.

(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)

schedule_to_start_timeout: Option<Duration>

Limits time an activity task can stay in a task queue before a worker picks it up. This timeout is always non retryable, as all a retry would achieve is to put it back into the same queue. Defaults to schedule_to_close_timeout if not specified.

(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)

start_to_close_timeout: Option<Duration>

Maximum time an activity is allowed to execute after being picked up by a worker. This timeout is always retryable. Either this or schedule_to_close_timeout must be specified.

(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)

heartbeat_timeout: Option<Duration>

Maximum permitted time between successful worker heartbeats.

retry_policy: Option<RetryPolicy>

The retry policy for the activity. Will never exceed schedule_to_close_timeout.

input: Option<Payloads>

Serialized arguments to the activity. These are passed as arguments to the activity function.

id_reuse_policy: i32

Defines whether to allow re-using the activity id from a previously closed activity. The default policy is ACTIVITY_ID_REUSE_POLICY_ALLOW_DUPLICATE.

id_conflict_policy: i32

Defines how to resolve an activity id conflict with a running activity. The default policy is ACTIVITY_ID_CONFLICT_POLICY_FAIL.

search_attributes: Option<SearchAttributes>

Search attributes for indexing.

header: Option<Header>

Header for context propagation and tracing purposes.

user_metadata: Option<UserMetadata>

Metadata for use by user interfaces to display the fixed as-of-start summary and details of the activity.

priority: Option<Priority>

Priority metadata.

Implementations

Source

impl StartActivityExecutionRequest

pub fn id_reuse_policy(&self) -> ActivityIdReusePolicy

Returns the enum value of id_reuse_policy, or the default if the field is set to an invalid enum value.

pub fn set_id_reuse_policy(&mut self, value: ActivityIdReusePolicy)

Sets id_reuse_policy to the provided enum value.

pub fn id_conflict_policy(&self) -> ActivityIdConflictPolicy

Returns the enum value of id_conflict_policy, or the default if the field is set to an invalid enum value.

pub fn set_id_conflict_policy(&mut self, value: ActivityIdConflictPolicy)

Sets id_conflict_policy to the provided enum value.