StartBatchOperationRequest

Struct StartBatchOperationRequest 

pub struct StartBatchOperationRequest {
    pub namespace: String,
    pub visibility_query: String,
    pub job_id: String,
    pub reason: String,
    pub executions: Vec<WorkflowExecution>,
    pub max_operations_per_second: f32,
    pub operation: Option<Operation>,
}

Fields

namespace: String

Namespace that contains the batch operation

visibility_query: String

Visibility query defines the the group of workflow to apply the batch operation This field and executions are mutually exclusive

job_id: String

Job ID defines the unique ID for the batch job

reason: String

Reason to perform the batch operation

executions: Vec<WorkflowExecution>

Executions to apply the batch operation This field and visibility_query are mutually exclusive

max_operations_per_second: f32

Limit for the number of operations processed per second within this batch. Its purpose is to reduce the stress on the system caused by batch operations, which helps to prevent system overload and minimize potential delays in executing ongoing tasks for user workers. Note that when no explicit limit is provided, the server will operate according to its limit defined by the dynamic configuration key worker.batcherRPS. This also applies if the value in this field exceeds the server’s configured limit.

operation: Option<Operation>

Operation input