pub struct UnpauseActivityRequest {
pub namespace: String,
pub execution: Option<WorkflowExecution>,
pub identity: String,
pub reset_attempts: bool,
pub reset_heartbeat: bool,
pub jitter: Option<Duration>,
pub activity: Option<Activity>,
}Fields
namespace: StringNamespace of the workflow which scheduled this activity.
execution: Option<WorkflowExecution>Execution info of the workflow which scheduled this activity
identity: StringThe identity of the client who initiated this request.
reset_attempts: boolProviding this flag will also reset the number of attempts.
reset_heartbeat: boolProviding this flag will also reset the heartbeat details.
jitter: Option<Duration>If set, the activity will start at a random time within the specified jitter duration.
activity: Option<Activity>either activity id or activity type must be provided