pub struct UpdateActivityOptionsRequest {
pub namespace: String,
pub execution: Option<WorkflowExecution>,
pub identity: String,
pub activity_options: Option<ActivityOptions>,
pub update_mask: Option<FieldMask>,
pub restore_original: bool,
pub activity: Option<Activity>,
}Expand description
NOTE: keep in sync with temporal.api.batch.v1.BatchOperationUpdateActivityOptions
Fields
namespace: StringNamespace of the workflow which scheduled this activity
execution: Option<WorkflowExecution>Execution info of the workflow which scheduled this activity
identity: StringThe identity of the client who initiated this request
activity_options: Option<ActivityOptions>Activity options. Partial updates are accepted and controlled by update_mask
update_mask: Option<FieldMask>Controls which fields from activity_options will be applied
restore_original: boolIf set, the activity options will be restored to the default. Default options are then options activity was created with. They are part of the first SCHEDULE event. This flag cannot be combined with any other option; if you supply restore_original together with other options, the request will be rejected.
activity: Option<Activity>either activity id, activity type or update_all must be provided