UpdateScheduleRequest

Struct UpdateScheduleRequest 

pub struct UpdateScheduleRequest {
    pub namespace: String,
    pub schedule_id: String,
    pub schedule: Option<Schedule>,
    pub conflict_token: Vec<u8>,
    pub identity: String,
    pub request_id: String,
    pub search_attributes: Option<SearchAttributes>,
}

Fields

namespace: String

The namespace of the schedule to update.

schedule_id: String

The id of the schedule to update.

schedule: Option<Schedule>

The new schedule. The four main fields of the schedule (spec, action, policies, state) are replaced completely by the values in this message.

conflict_token: Vec<u8>

This can be the value of conflict_token from a DescribeScheduleResponse, which will cause this request to fail if the schedule has been modified between the Describe and this Update. If missing, the schedule will be updated unconditionally.

identity: String

The identity of the client who initiated this request.

request_id: String

A unique identifier for this update request for idempotence. Typically UUIDv4.

search_attributes: Option<SearchAttributes>

Schedule search attributes to be updated. Do not set this field if you do not want to update the search attributes. A non-null empty object will set the search attributes to an empty map. Note: you cannot only update the search attributes with UpdateScheduleRequest, you must also set the schedule field; otherwise, it will unset the schedule.