pub struct UpdateTaskQueueConfigRequest {
pub namespace: String,
pub identity: String,
pub task_queue: String,
pub task_queue_type: i32,
pub update_queue_rate_limit: Option<RateLimitUpdate>,
pub update_fairness_key_rate_limit_default: Option<RateLimitUpdate>,
pub set_fairness_weight_overrides: HashMap<String, f32>,
pub unset_fairness_weight_overrides: Vec<String>,
}Fields
namespace: Stringidentity: Stringtask_queue: StringSelects the task queue to update.
task_queue_type: i32update_queue_rate_limit: Option<RateLimitUpdate>Update to queue-wide rate limit.
If not set, this configuration is unchanged.
NOTE: A limit set by the worker is overriden; and restored again when reset.
If the rate_limit field in the RateLimitUpdate is missing, remove the existing rate limit.
update_fairness_key_rate_limit_default: Option<RateLimitUpdate>Update to the default fairness key rate limit.
If not set, this configuration is unchanged.
If the rate_limit field in the RateLimitUpdate is missing, remove the existing rate limit.
set_fairness_weight_overrides: HashMap<String, f32>If set, overrides the fairness weight for each specified fairness key. Fairness keys not listed in this map will keep their existing overrides (if any).
unset_fairness_weight_overrides: Vec<String>If set, removes any existing fairness weight overrides for each specified fairness key. Fairness weights for corresponding keys fall back to the values set during task creation (if any), or to the default weight of 1.0.
Implementations
Sourceimpl UpdateTaskQueueConfigRequest
impl UpdateTaskQueueConfigRequest
Sourcepub fn task_queue_type(&self) -> TaskQueueType
pub fn task_queue_type(&self) -> TaskQueueType
Returns the enum value of task_queue_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_task_queue_type(&mut self, value: TaskQueueType)
pub fn set_task_queue_type(&mut self, value: TaskQueueType)
Sets task_queue_type to the provided enum value.