#[non_exhaustive]pub enum SearchAttributeError {
PayloadConversion(PayloadConversionError),
InvalidPayload {
reason: String,
},
InvalidTimestamp(String),
}Expand description
Errors arising from search attribute serialization or deserialization.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PayloadConversion(PayloadConversionError)
Payload conversion failed.
InvalidPayload
The payload is missing required metadata or has an unexpected encoding.
InvalidTimestamp(String)
A timestamp value could not be formatted or parsed as RFC3339.