#[non_exhaustive]pub struct WorkflowExecution { /* private fields */ }Expand description
Identifies a workflow execution by workflow and run ID.
Implementations
Sourceimpl WorkflowExecution
impl WorkflowExecution
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
The workflow ID.
Sourcepub fn set_workflow_id(
&mut self,
workflow_id: impl Into<String>,
) -> &mut WorkflowExecution
pub fn set_workflow_id( &mut self, workflow_id: impl Into<String>, ) -> &mut WorkflowExecution
Set the workflow ID.
Sourcepub fn set_run_id(
&mut self,
run_id: impl Into<String>,
) -> &mut WorkflowExecution
pub fn set_run_id( &mut self, run_id: impl Into<String>, ) -> &mut WorkflowExecution
Set the run ID.
Sourcepub fn raw(&self) -> &WorkflowExecution
pub fn raw(&self) -> &WorkflowExecution
Access the underlying workflow execution protobuf.
Sourcepub fn into_raw(self) -> WorkflowExecution
pub fn into_raw(self) -> WorkflowExecution
Consume this wrapper and return the underlying workflow execution protobuf.