#[non_exhaustive]pub enum TaskQueueLabelStrategy {
UseNormal,
UseNormalAndSticky,
}Expand description
Determines how the task_queue label value is set on metrics.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UseNormal
Always use the normal task queue name, including for actions relating to sticky queues.
UseNormalAndSticky
Use the sticky queue name when recording metrics operating on sticky queues.