telemetry_init_fallback

Function telemetry_init_fallback 

pub fn telemetry_init_fallback() -> Result<(), Error>
WARNING: Calling can cause panics because of https://github.com/tokio-rs/tracing/issues/1656 Lang must not start using until resolved

Initialize the fallback global handler. All lang SDKs should call this somewhere, once, at startup, as it initializes a fallback handler for any dependencies (looking at you, otel) that don’t provide good ways to customize their tracing usage. It sets a WARN-level global filter that uses the default console logger.