pub struct Counter { /* private fields */ }Expand description
A counter metric instrument that optionally tracks values in memory for heartbeating.
Implementations
Sourceimpl Counter
impl Counter
Sourcepub fn new(
inner: Arc<dyn MetricAttributable<Box<dyn CounterBase>> + Send + Sync>,
) -> Self
pub fn new( inner: Arc<dyn MetricAttributable<Box<dyn CounterBase>> + Send + Sync>, ) -> Self
Create a new counter from an attributable metric source.
Sourcepub fn new_with_in_memory(
primary: Arc<dyn MetricAttributable<Box<dyn CounterBase>> + Send + Sync>,
in_memory: HeartbeatMetricType,
) -> Self
pub fn new_with_in_memory( primary: Arc<dyn MetricAttributable<Box<dyn CounterBase>> + Send + Sync>, in_memory: HeartbeatMetricType, ) -> Self
Create a new counter with an additional in-memory tracker for heartbeat reporting.
Sourcepub fn add(&self, value: u64, attributes: &MetricAttributes)
pub fn add(&self, value: u64, attributes: &MetricAttributes)
Increment the counter by value with the given attributes.
Sourcepub fn update_attributes(&mut self, new_attributes: MetricAttributes)
pub fn update_attributes(&mut self, new_attributes: MetricAttributes)
Replace the attributes on the primary metric.