pub struct HistogramDuration { /* private fields */ }Expand description
A histogram that records Duration values, optionally tracking in memory for heartbeating.
Implementations
Sourceimpl HistogramDuration
impl HistogramDuration
Sourcepub fn new(
inner: Arc<dyn MetricAttributable<Box<dyn HistogramDurationBase>> + Send + Sync>,
) -> Self
pub fn new( inner: Arc<dyn MetricAttributable<Box<dyn HistogramDurationBase>> + Send + Sync>, ) -> Self
Create a new duration histogram from an attributable metric source.
Sourcepub fn new_with_in_memory(
primary: Arc<dyn MetricAttributable<Box<dyn HistogramDurationBase>> + Send + Sync>,
in_memory: HeartbeatMetricType,
) -> Self
pub fn new_with_in_memory( primary: Arc<dyn MetricAttributable<Box<dyn HistogramDurationBase>> + Send + Sync>, in_memory: HeartbeatMetricType, ) -> Self
Create a new duration histogram with an additional in-memory tracker for heartbeat reporting.
Sourcepub fn record(&self, value: Duration, attributes: &MetricAttributes)
pub fn record(&self, value: Duration, attributes: &MetricAttributes)
Record a duration value with the given attributes.
Sourcepub fn update_attributes(&mut self, new_attributes: MetricAttributes)
pub fn update_attributes(&mut self, new_attributes: MetricAttributes)
Replace the attributes on the primary metric.