pub struct TemporalMeter { /* private fields */ }Expand description
Wraps a CoreMeter to enable the attaching of default labels to metrics. Cloning is cheap.
Implementations
Sourceimpl TemporalMeter
impl TemporalMeter
Sourcepub fn new(
meter: Arc<dyn CoreMeter>,
default_attribs: NewAttributes,
task_queue_label_strategy: TaskQueueLabelStrategy,
) -> Self
pub fn new( meter: Arc<dyn CoreMeter>, default_attribs: NewAttributes, task_queue_label_strategy: TaskQueueLabelStrategy, ) -> Self
Create a new TemporalMeter.
Sourcepub fn get_default_attributes(&self) -> &MetricAttributes
pub fn get_default_attributes(&self) -> &MetricAttributes
Returns the default attributes this meter uses.
Sourcepub fn get_task_queue_label_strategy(&self) -> &TaskQueueLabelStrategy
pub fn get_task_queue_label_strategy(&self) -> &TaskQueueLabelStrategy
Returns the Task Queue labeling strategy this meter uses.
Sourcepub fn merge_attributes(&mut self, new_attribs: NewAttributes)
pub fn merge_attributes(&mut self, new_attribs: NewAttributes)
Add some new attributes to the default set already in this meter.