pub struct PrometheusExporterOptions {
pub socket_addr: SocketAddr,
pub global_tags: HashMap<String, String>,
pub counters_total_suffix: bool,
pub unit_suffix: bool,
pub use_seconds_for_durations: bool,
pub histogram_bucket_overrides: HistogramBucketOverrides,
}Expand description
Options for exporting metrics to Prometheus
Fields
socket_addr: SocketAddrThe address the Prometheus exporter HTTP server will bind to.
A map of tags to be applied to all metrics
counters_total_suffix: boolIf set true, all counters will include a “_total” suffix
unit_suffix: boolIf set true, all histograms will include the unit in their name as a suffix. Ex: “_milliseconds”.
use_seconds_for_durations: boolIf set to true, use f64 seconds for durations instead of u64 milliseconds
histogram_bucket_overrides: HistogramBucketOverridesOverrides for histogram buckets. Units depend on the value of use_seconds_for_durations.
Implementations
Sourceimpl PrometheusExporterOptions
impl PrometheusExporterOptions
Sourcepub fn builder() -> PrometheusExporterOptionsBuilder
pub fn builder() -> PrometheusExporterOptionsBuilder
Create an instance of PrometheusExporterOptions using the builder syntax