PrometheusExporterOptionsBuilder

Struct PrometheusExporterOptionsBuilder 

pub struct PrometheusExporterOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PrometheusExporterOptionsBuilder<S>

pub fn build(self) -> PrometheusExporterOptions
where S: IsComplete,

Finish building and return the requested object

pub fn socket_addr( self, value: SocketAddr, ) -> PrometheusExporterOptionsBuilder<SetSocketAddr<S>>
where S::SocketAddr: IsUnset,

Required.

The address the Prometheus exporter HTTP server will bind to.

pub fn global_tags( self, value: HashMap<String, String>, ) -> PrometheusExporterOptionsBuilder<SetGlobalTags<S>>
where S::GlobalTags: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

A map of tags to be applied to all metrics

pub fn maybe_global_tags( self, value: Option<HashMap<String, String>>, ) -> PrometheusExporterOptionsBuilder<SetGlobalTags<S>>
where S::GlobalTags: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

A map of tags to be applied to all metrics

pub fn counters_total_suffix( self, value: bool, ) -> PrometheusExporterOptionsBuilder<SetCountersTotalSuffix<S>>
where S::CountersTotalSuffix: IsUnset,

Optional (Some / Option setters). Default: false.

If set true, all counters will include a “_total” suffix

pub fn maybe_counters_total_suffix( self, value: Option<bool>, ) -> PrometheusExporterOptionsBuilder<SetCountersTotalSuffix<S>>
where S::CountersTotalSuffix: IsUnset,

Optional (Some / Option setters). Default: false.

If set true, all counters will include a “_total” suffix

pub fn unit_suffix( self, value: bool, ) -> PrometheusExporterOptionsBuilder<SetUnitSuffix<S>>
where S::UnitSuffix: IsUnset,

Optional (Some / Option setters). Default: false.

If set true, all histograms will include the unit in their name as a suffix. Ex: “_milliseconds”.

pub fn maybe_unit_suffix( self, value: Option<bool>, ) -> PrometheusExporterOptionsBuilder<SetUnitSuffix<S>>
where S::UnitSuffix: IsUnset,

Optional (Some / Option setters). Default: false.

If set true, all histograms will include the unit in their name as a suffix. Ex: “_milliseconds”.

pub fn use_seconds_for_durations( self, value: bool, ) -> PrometheusExporterOptionsBuilder<SetUseSecondsForDurations<S>>
where S::UseSecondsForDurations: IsUnset,

Optional (Some / Option setters). Default: false.

If set to true, use f64 seconds for durations instead of u64 milliseconds

pub fn maybe_use_seconds_for_durations( self, value: Option<bool>, ) -> PrometheusExporterOptionsBuilder<SetUseSecondsForDurations<S>>
where S::UseSecondsForDurations: IsUnset,

Optional (Some / Option setters). Default: false.

If set to true, use f64 seconds for durations instead of u64 milliseconds

pub fn histogram_bucket_overrides( self, value: HistogramBucketOverrides, ) -> PrometheusExporterOptionsBuilder<SetHistogramBucketOverrides<S>>
where S::HistogramBucketOverrides: IsUnset,

Optional (Some / Option setters). Default: <HistogramBucketOverrides as Default>::default().

Overrides for histogram buckets. Units depend on the value of use_seconds_for_durations.

pub fn maybe_histogram_bucket_overrides( self, value: Option<HistogramBucketOverrides>, ) -> PrometheusExporterOptionsBuilder<SetHistogramBucketOverrides<S>>
where S::HistogramBucketOverrides: IsUnset,

Optional (Some / Option setters). Default: <HistogramBucketOverrides as Default>::default().

Overrides for histogram buckets. Units depend on the value of use_seconds_for_durations.