pub struct TelemetryInstance { /* private fields */ }Expand description
Holds initialized tracing/metrics exporters, etc
Implementations
Sourceimpl TelemetryInstance
impl TelemetryInstance
Sourcepub fn trace_subscriber(&self) -> Option<Arc<dyn Subscriber + Send + Sync>>
pub fn trace_subscriber(&self) -> Option<Arc<dyn Subscriber + Send + Sync>>
Return the trace subscriber associated with the telemetry options/instance. Can be used
to manually set the default for a thread or globally using the tracing crate, or with
set_trace_subscriber_for_current_thread.
Sourcepub fn attach_late_init_metrics(&mut self, meter: Arc<dyn CoreMeter + 'static>)
pub fn attach_late_init_metrics(&mut self, meter: Arc<dyn CoreMeter + 'static>)
Some metric meters cannot be initialized until after a tokio runtime has started and after other telemetry has initted (ex: prometheus). They can be attached here.
Sourcepub fn get_temporal_metric_meter(&self) -> Option<TemporalMeter>
pub fn get_temporal_metric_meter(&self) -> Option<TemporalMeter>
Returns our wrapper for metric meters, including the metric_prefix from
TelemetryOptions. This should be used to initialize clients or for any other
temporal-owned metrics. User defined metrics should use Self::get_metric_meter.
Sourcepub fn get_metric_meter(&self) -> Option<TemporalMeter>
pub fn get_metric_meter(&self) -> Option<TemporalMeter>
Returns our wrapper for metric meters, including attaching the service name if enabled.