TelemetryOptionsBuilder

Struct TelemetryOptionsBuilder 

pub struct TelemetryOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TelemetryOptionsBuilder<S>

pub fn build(self) -> TelemetryOptions
where S: IsComplete,

Finish building and return the requested object

pub fn logging( self, value: impl Into<Logger>, ) -> TelemetryOptionsBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters).

Optional logger - set as None to disable.

pub fn maybe_logging( self, value: Option<impl Into<Logger>>, ) -> TelemetryOptionsBuilder<SetLogging<S>>
where S::Logging: IsUnset,

Optional (Some / Option setters).

Optional logger - set as None to disable.

pub fn metrics( self, value: impl Into<Arc<dyn CoreMeter>>, ) -> TelemetryOptionsBuilder<SetMetrics<S>>
where S::Metrics: IsUnset,

Optional (Some / Option setters).

Optional metrics exporter - set as None to disable.

pub fn maybe_metrics( self, value: Option<impl Into<Arc<dyn CoreMeter>>>, ) -> TelemetryOptionsBuilder<SetMetrics<S>>
where S::Metrics: IsUnset,

Optional (Some / Option setters).

Optional metrics exporter - set as None to disable.

pub fn attach_service_name( self, value: bool, ) -> TelemetryOptionsBuilder<SetAttachServiceName<S>>
where S::AttachServiceName: IsUnset,

Optional (Some / Option setters). Default: true.

If set true (the default) explicitly attach a service_name label to all metrics. Turn this off if your collection system supports the target_info metric from the OpenMetrics spec. For more, see here

pub fn maybe_attach_service_name( self, value: Option<bool>, ) -> TelemetryOptionsBuilder<SetAttachServiceName<S>>
where S::AttachServiceName: IsUnset,

Optional (Some / Option setters). Default: true.

If set true (the default) explicitly attach a service_name label to all metrics. Turn this off if your collection system supports the target_info metric from the OpenMetrics spec. For more, see here

pub fn metric_prefix( self, value: String, ) -> TelemetryOptionsBuilder<SetMetricPrefix<S>>
where S::MetricPrefix: IsUnset,

Optional (Some / Option setters). Default: METRIC_PREFIX.to_string().

A prefix to be applied to all core-created metrics. Defaults to “temporal_”.

pub fn maybe_metric_prefix( self, value: Option<String>, ) -> TelemetryOptionsBuilder<SetMetricPrefix<S>>
where S::MetricPrefix: IsUnset,

Optional (Some / Option setters). Default: METRIC_PREFIX.to_string().

A prefix to be applied to all core-created metrics. Defaults to “temporal_”.

pub fn subscriber_override( self, value: Arc<dyn Subscriber + Send + Sync>, ) -> TelemetryOptionsBuilder<SetSubscriberOverride<S>>
where S::SubscriberOverride: IsUnset,

Optional (Some / Option setters).

If provided, logging config will be ignored and this explicit subscriber will be used for all logging and traces.

pub fn maybe_subscriber_override( self, value: Option<Arc<dyn Subscriber + Send + Sync>>, ) -> TelemetryOptionsBuilder<SetSubscriberOverride<S>>
where S::SubscriberOverride: IsUnset,

Optional (Some / Option setters).

If provided, logging config will be ignored and this explicit subscriber will be used for all logging and traces.

pub fn task_queue_label_strategy( self, value: TaskQueueLabelStrategy, ) -> TelemetryOptionsBuilder<SetTaskQueueLabelStrategy<S>>
where S::TaskQueueLabelStrategy: IsUnset,

Optional (Some / Option setters). Default: TaskQueueLabelStrategy::UseNormal.

See TaskQueueLabelStrategy.

pub fn maybe_task_queue_label_strategy( self, value: Option<TaskQueueLabelStrategy>, ) -> TelemetryOptionsBuilder<SetTaskQueueLabelStrategy<S>>
where S::TaskQueueLabelStrategy: IsUnset,

Optional (Some / Option setters). Default: TaskQueueLabelStrategy::UseNormal.

See TaskQueueLabelStrategy.