CoreTelemetry

Trait CoreTelemetry 

pub trait CoreTelemetry {
    // Required method
    fn fetch_buffered_logs(&self) -> Vec<CoreLog>;
}
Each core runtime instance has a telemetry subsystem associated with it, this trait defines the operations that lang might want to perform on that telemetry after it’s initialized.

Required Methods

fn fetch_buffered_logs(&self) -> Vec<CoreLog>

Each worker buffers logs that should be shuttled over to lang so that they may be rendered with the user’s desired logging library. Use this function to grab the most recent buffered logs since the last time it was called. A fixed number of such logs are retained at maximum, with the oldest being dropped when full.

Returns the list of logs from oldest to newest. Returns an empty vec if the feature is not configured.

Implementors