HasWorkflowDefinition

Trait HasWorkflowDefinition 

pub trait HasWorkflowDefinition: WorkflowDefinition {
    type Run: WorkflowDefinition;
}
Indicates that a type is associated with a WorkflowDefinition, enabling typed signal, query, and update methods on WorkflowHandle.

Structs annotated with #[workflow_methods] implement this trait automatically.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors