UpdateDefinition

Trait UpdateDefinition 

pub trait UpdateDefinition {
    type Workflow: WorkflowDefinition;
    type Input: TemporalDeserializable + TemporalSerializable + 'static;
    type Output: TemporalDeserializable + TemporalSerializable + 'static;

    // Required method
    fn name(&self) -> &str;
}
Implement on a marker struct to define an update.

Typically, you will want to use the #[update] attribute inside a #[workflow_methods] macro to define updates. However, this trait may be implemented manually if desired.

Required Associated Types

type Workflow: WorkflowDefinition

The workflow type this update belongs to

type Input: TemporalDeserializable + TemporalSerializable + 'static

Type of the input argument to the update.

type Output: TemporalDeserializable + TemporalSerializable + 'static

Type of the output of the update.

Required Methods

fn name(&self) -> &str

The workflow type name.

Implementors