WorkflowDefinition

Trait WorkflowDefinition 

pub trait WorkflowDefinition {
    type Input: TemporalDeserializable + TemporalSerializable + 'static;
    type Output: TemporalDeserializable + TemporalSerializable + 'static;

    // Required method
    fn name(&self) -> &str;
}
Implement on a marker struct to define a workflow.

Typically, you will want to use the #[workflow] and #[workflow_methods] macros to define workflows. However, this trait may be implemented manually if desired.

Required Associated Types

type Input: TemporalDeserializable + TemporalSerializable + 'static

Type of the input argument to the workflow

type Output: TemporalDeserializable + TemporalSerializable + 'static

Type of the output of the workflow

Required Methods

fn name(&self) -> &str

The workflow type name

Implementors