Module worker

Module worker 

Contains types that are needed by both the client and the sdk when configuring / interacting with workers.

Structs

WorkerDeploymentOptions
Configuration for worker deployment versioning.
WorkerDeploymentVersion
Identifies a specific version of a worker deployment.
WorkerTaskTypes
Specifies which task types a worker will poll for.

Functions

build_id_from_current_exe
Build ID derived from hashing the on-disk bytes of the current executable. Deterministic across machines for the same binary. Cached per-process.