pub struct WorkerDeploymentOptions {
pub version: WorkerDeploymentVersion,
pub use_worker_versioning: bool,
pub default_versioning_behavior: Option<VersioningBehavior>,
}Expand description
Configuration for worker deployment versioning.
Fields
version: WorkerDeploymentVersionThe deployment version of this worker.
use_worker_versioning: boolIf set, opts in to the Worker Deployment Versioning feature, meaning this worker will only receive tasks for workflows it claims to be compatible with.
default_versioning_behavior: Option<VersioningBehavior>The default versioning behavior to use for workflows that do not pass one to Core.
It is a startup-time error to specify Some(Unspecified) here.
Implementations
Sourceimpl WorkerDeploymentOptions
impl WorkerDeploymentOptions
Sourcepub fn from_build_id(build_id: String) -> Self
pub fn from_build_id(build_id: String) -> Self
Create deployment options from just a build ID, without opting into worker versioning.