pub struct RawValue {
pub payloads: Vec<Payload>,
}Expand description
An unconverted set of payloads, used when the caller wants to defer deserialization.
Fields
payloads: Vec<Payload>The underlying payloads.
Implementations
Sourceimpl RawValue
impl RawValue
Sourcepub fn empty() -> Self
pub fn empty() -> Self
A RawValue representing no meaningful data, containing a single default payload. This ensures the value can still be serialized as a single payload.
Sourcepub fn from_value<T: TemporalSerializable + 'static>(
value: &T,
converter: &PayloadConverter,
) -> RawValue
pub fn from_value<T: TemporalSerializable + 'static>( value: &T, converter: &PayloadConverter, ) -> RawValue
Create a RawValue by serializing a value with the given converter.
Sourcepub fn to_value<T: TemporalDeserializable + 'static>(
self,
converter: &PayloadConverter,
) -> T
pub fn to_value<T: TemporalDeserializable + 'static>( self, converter: &PayloadConverter, ) -> T
Deserialize this RawValue into a typed value using the given converter.