Shared error types used across Temporal SDK crates.
Modules
- application_
failure_ builder - Tools for manipulating the type state of
ApplicationFailureBuilder.
Structs
- Activity
Failure Error - A normalized activity failure wrapper.
- Application
Failure - User-authored application failure metadata that can be converted into a Temporal failure.
- Application
Failure Builder - Use builder syntax to set the inputs and finish with
build(). - Cancelled
Error - A normalized cancellation failure.
- Child
Workflow Failure Error - A normalized child-workflow execution failure wrapper.
- Child
Workflow Signal Failure Error - A normalized child-workflow signal failure wrapper.
- Failure
Payloads - Payloads attached to a failure, either as a deferred outbound value or decoded inbound payloads.
- Incoming
Nexus Handler Error - A normalized nexus handler failure wrapper.
- Incoming
Nexus Operation Execution Error - A normalized nexus operation failure wrapper.
- Reset
Workflow Error - A normalized reset-workflow failure.
- Server
Error - A normalized server failure.
- Terminated
Error - A normalized terminated failure.
- Timeout
Error - A normalized timeout failure.
Enums
- Activity
Execution Error - Error type for activity execution outcomes.
- Child
Workflow Execution Error - Error returned when a child workflow execution fails.
- Child
Workflow Signal Error - Error returned when signaling a child workflow fails.
- Child
Workflow Start Error - Error returned when starting a child workflow fails.
- Incoming
Error - A normalized incoming Temporal failure decoded from a protobuf
Failure. - Outgoing
Activity Error - A typed outbound activity error.
- Outgoing
Error - A typed outbound error surface used before encoding to a Temporal failure proto.
- Outgoing
Workflow Error - A typed outbound workflow failure.