Trait State Copy item path Source pub trait State: Sized {
type TypeName ;
type NonRetryable ;
type NextRetryDelay ;
type Category ;
type Details ;
type Failure ;
type Cause ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member type_name.
It can implement either IsSet or IsUnset
Type state of the member non_retryable.
It can implement either IsSet or IsUnset
Type state of the member next_retry_delay.
It can implement either IsSet or IsUnset
Type state of the member category.
It can implement either IsSet or IsUnset
Type state of the member details.
It can implement either IsSet or IsUnset
Type state of the member failure.
It can implement either IsSet or IsUnset
Type state of the member cause.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.