pub enum IncomingError {
Application(ApplicationFailure),
Timeout(TimeoutError),
Cancelled(CancelledError),
Terminated(TerminatedError),
Server(ServerError),
ResetWorkflow(ResetWorkflowError),
Activity(ActivityFailureError),
ChildWorkflowExecution(ChildWorkflowFailureError),
NexusOperationExecution(IncomingNexusOperationExecutionError),
NexusHandler(IncomingNexusHandlerError),
}Expand description
A normalized incoming Temporal failure decoded from a protobuf Failure.
Variants
Application(ApplicationFailure)
A decoded application failure.
Timeout(TimeoutError)
A decoded timeout failure.
Cancelled(CancelledError)
A decoded cancellation failure.
Terminated(TerminatedError)
A decoded terminated failure.
Server(ServerError)
A decoded server failure.
ResetWorkflow(ResetWorkflowError)
A decoded reset-workflow failure.
Activity(ActivityFailureError)
A decoded activity failure wrapper.
ChildWorkflowExecution(ChildWorkflowFailureError)
A decoded child-workflow failure wrapper.
NexusOperationExecution(IncomingNexusOperationExecutionError)
A decoded nexus operation failure wrapper.
NexusHandler(IncomingNexusHandlerError)
A decoded nexus handler failure wrapper.
Implementations
Sourceimpl IncomingError
impl IncomingError
Sourcepub fn failure(&self) -> &Failure
pub fn failure(&self) -> &Failure
Returns the original failure proto for this normalized error.
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized cause, if any.
Sourcepub fn into_failure(self) -> Failure
pub fn into_failure(self) -> Failure
Consumes this normalized error and returns the retained proto failure.
Sourcepub fn as_timeout(&self) -> Option<&TimeoutError>
pub fn as_timeout(&self) -> Option<&TimeoutError>
If the IncomingError is a timeout, returns the associated TimeoutError.
Sourcepub fn as_cancelled(&self) -> Option<&CancelledError>
pub fn as_cancelled(&self) -> Option<&CancelledError>
If the IncomingError is a cancellation, returns the associated CancelledError.