pub struct Start {Show 18 fields
pub workflow_namespace: String,
pub workflow_type: String,
pub workflow_execution: Option<WorkflowExecution>,
pub activity_id: String,
pub activity_type: String,
pub header_fields: HashMap<String, Payload>,
pub input: Vec<Payload>,
pub heartbeat_details: Vec<Payload>,
pub scheduled_time: Option<Timestamp>,
pub current_attempt_scheduled_time: Option<Timestamp>,
pub started_time: Option<Timestamp>,
pub attempt: u32,
pub schedule_to_close_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub retry_policy: Option<RetryPolicy>,
pub priority: Option<Priority>,
pub is_local: bool,
}Expand description
Begin executing an activity
Fields
workflow_namespace: StringThe namespace the workflow lives in
workflow_type: StringThe workflow’s type name or function identifier
workflow_execution: Option<WorkflowExecution>The workflow execution which requested this activity
activity_id: StringThe activity’s ID
activity_type: StringThe activity’s type name or function identifier
header_fields: HashMap<String, Payload>input: Vec<Payload>Arguments to the activity
heartbeat_details: Vec<Payload>The last details that were recorded by a heartbeat when this task was generated
scheduled_time: Option<Timestamp>When the task was first scheduled
current_attempt_scheduled_time: Option<Timestamp>When this current attempt at the task was scheduled
started_time: Option<Timestamp>When this attempt was started, which is to say when core received it by polling.
attempt: u32schedule_to_close_timeout: Option<Duration>Timeout from the first schedule time to completion
start_to_close_timeout: Option<Duration>Timeout from starting an attempt to reporting its result
heartbeat_timeout: Option<Duration>If set a heartbeat must be reported within this interval
retry_policy: Option<RetryPolicy>This is an actual retry policy the service uses. It can be different from the one provided (or not) during activity scheduling as the service can override the provided one in case its values are not specified or exceed configured system limits.
priority: Option<Priority>Priority of this activity. Local activities will always have this field set to the default.
is_local: boolSet to true if this is a local activity. Note that heartbeating does not apply to local activities.