pub struct ActivityOptions {
pub task_queue: Option<TaskQueue>,
pub schedule_to_close_timeout: Option<Duration>,
pub schedule_to_start_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub retry_policy: Option<RetryPolicy>,
pub priority: Option<Priority>,
}Fields
task_queue: Option<TaskQueue>schedule_to_close_timeout: Option<Duration>Indicates how long the caller is willing to wait for an activity completion. Limits how long
retries will be attempted. Either this or start_to_close_timeout must be specified.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
schedule_to_start_timeout: Option<Duration>Limits time an activity task can stay in a task queue before a worker picks it up. This
timeout is always non retryable, as all a retry would achieve is to put it back into the same
queue. Defaults to schedule_to_close_timeout or workflow execution timeout if not
specified.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
start_to_close_timeout: Option<Duration>Maximum time an activity is allowed to execute after being picked up by a worker. This
timeout is always retryable. Either this or schedule_to_close_timeout must be
specified.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
heartbeat_timeout: Option<Duration>Maximum permitted time between successful worker heartbeats.
retry_policy: Option<RetryPolicy>The retry policy for the activity. Will never exceed schedule_to_close_timeout.
priority: Option<Priority>Priority metadata. If this message is not present, or any fields are not present, they inherit the values from the workflow.