pub struct UserGroup {
pub id: String,
pub resource_version: String,
pub spec: Option<UserGroupSpec>,
pub state_deprecated: String,
pub state: i32,
pub async_operation_id: String,
pub created_time: Option<Timestamp>,
pub last_modified_time: Option<Timestamp>,
}Fields
id: StringThe id of the group
resource_version: StringThe current version of the group specification The next update operation will have to include this version
spec: Option<UserGroupSpec>The group specification
state_deprecated: StringThe current state of the group. Deprecated: Not supported after v0.3.0 api version. Use state instead. temporal:versioning:max_version=v0.3.0
state: i32The current state of the group. For any failed state, reach out to Temporal Cloud support for remediation. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=state_deprecated
async_operation_id: StringThe id of the async operation that is creating/updating/deleting the group, if any
created_time: Option<Timestamp>The date and time when the group was created
last_modified_time: Option<Timestamp>The date and time when the group was last modified Will not be set if the group has never been modified
Implementations
Sourceimpl UserGroup
impl UserGroup
Sourcepub fn state(&self) -> ResourceState
pub fn state(&self) -> ResourceState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ResourceState)
pub fn set_state(&mut self, value: ResourceState)
Sets state to the provided enum value.