pub struct Namespace {Show 15 fields
pub namespace: String,
pub resource_version: String,
pub spec: Option<NamespaceSpec>,
pub state_deprecated: String,
pub state: i32,
pub async_operation_id: String,
pub endpoints: Option<Endpoints>,
pub active_region: String,
pub limits: Option<Limits>,
pub private_connectivities: Vec<PrivateConnectivity>,
pub created_time: Option<Timestamp>,
pub last_modified_time: Option<Timestamp>,
pub region_status: HashMap<String, NamespaceRegionStatus>,
pub connectivity_rules: Vec<ConnectivityRule>,
pub tags: HashMap<String, String>,
}Fields
namespace: StringThe namespace identifier.
resource_version: StringThe current version of the namespace specification. The next update operation will have to include this version.
spec: Option<NamespaceSpec>The namespace specification.
state_deprecated: StringThe current state of the namespace. Deprecated: Not supported after v0.3.0 api version. Use state instead. temporal:versioning:max_version=v0.3.0
state: i32The current state of the namespace. For any failed state, reach out to Temporal Cloud support for remediation. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=state_deprecated
async_operation_id: StringThe id of the async operation that is creating/updating/deleting the namespace, if any.
endpoints: Option<Endpoints>The endpoints for the namespace.
active_region: StringThe currently active region for the namespace.
limits: Option<Limits>The limits set on the namespace currently.
private_connectivities: Vec<PrivateConnectivity>The private connectivities for the namespace, if any.
created_time: Option<Timestamp>The date and time when the namespace was created.
last_modified_time: Option<Timestamp>The date and time when the namespace was last modified. Will not be set if the namespace has never been modified.
region_status: HashMap<String, NamespaceRegionStatus>The status of each region where the namespace is available. The id of the region is the key and the status is the value of the map.
connectivity_rules: Vec<ConnectivityRule>The connectivity rules that are set on this namespace.
The tags for the namespace.
Implementations
Sourceimpl Namespace
impl Namespace
Sourcepub fn state(&self) -> ResourceState
pub fn state(&self) -> ResourceState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ResourceState)
pub fn set_state(&mut self, value: ResourceState)
Sets state to the provided enum value.