pub struct NamespaceRegionStatus {
pub state_deprecated: String,
pub state: i32,
pub async_operation_id: String,
}Fields
state_deprecated: String👎Deprecated
The current state of the namespace region. Possible values: adding, active, passive, removing, failed. For any failed state, reach out to Temporal Cloud support for remediation. Deprecated: Not supported after v0.3.0 api version. Use state instead. temporal:versioning:max_version=v0.3.0
state: i32The current state of the namespace region. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=state_deprecated
async_operation_id: StringThe id of the async operation that is making changes to where the namespace is available, if any.
Implementations