pub struct NamespaceSpec {
pub name: String,
pub regions: Vec<String>,
pub retention_days: i32,
pub mtls_auth: Option<MtlsAuthSpec>,
pub api_key_auth: Option<ApiKeyAuthSpec>,
pub custom_search_attributes: HashMap<String, String>,
pub search_attributes: HashMap<String, i32>,
pub codec_server: Option<CodecServerSpec>,
pub lifecycle: Option<LifecycleSpec>,
pub high_availability: Option<HighAvailabilitySpec>,
pub connectivity_rule_ids: Vec<String>,
}Fields
name: StringThe name to use for the namespace.
This will create a namespace that’s available at ‘
regions: Vec<String>The ids of the regions where the namespace should be available. The GetRegions API can be used to get the list of valid region ids. Specifying more than one region makes the namespace “global”, which is currently a preview only feature with restricted access. Please reach out to Temporal support for more information on global namespaces. When provisioned the global namespace will be active on the first region in the list and passive on the rest. Number of supported regions is 2. The regions is immutable. Once set, it cannot be changed. Example: [“aws-us-west-2”].
retention_days: i32The number of days the workflows data will be retained for. Changes to the retention period may impact your storage costs. Any changes to the retention period will be applied to all new running workflows.
mtls_auth: Option<MtlsAuthSpec>The mTLS auth configuration for the namespace. If unspecified, mTLS will be disabled.
api_key_auth: Option<ApiKeyAuthSpec>The API key auth configuration for the namespace. If unspecified, API keys will be disabled. temporal:versioning:min_version=v0.2.0
custom_search_attributes: HashMap<String, String>The custom search attributes to use for the namespace. The name of the attribute is the key and the type is the value. Supported attribute types: text, keyword, int, double, bool, datetime, keyword_list. NOTE: currently deleting a search attribute is not supported. Optional, default is empty. Deprecated: Not supported after v0.3.0 api version. Use search_attributes instead. temporal:versioning:max_version=v0.3.0
search_attributes: HashMap<String, i32>The custom search attributes to use for the namespace. The name of the attribute is the key and the type is the value. Note: currently deleting a search attribute is not supported. Optional, default is empty. temporal:versioning:min_version=v0.3.0 temporal:enums:replaces=custom_search_attributes
codec_server: Option<CodecServerSpec>Codec server spec used by UI to decode payloads for all users interacting with this namespace. Optional, default is unset.
lifecycle: Option<LifecycleSpec>The lifecycle configuration for the namespace. temporal:versioning:min_version=v0.4.0
high_availability: Option<HighAvailabilitySpec>The high availability configuration for the namespace. temporal:versioning:min_version=v0.4.0
connectivity_rule_ids: Vec<String>The private connectivity configuration for the namespace. This will apply the connectivity rules specified to the namespace. temporal:versioning:min_version=v0.6.0
Implementations
Sourceimpl NamespaceSpec
impl NamespaceSpec
Sourcepub fn get_search_attributes(&self, key: &str) -> Option<SearchAttributeType>
pub fn get_search_attributes(&self, key: &str) -> Option<SearchAttributeType>
Returns the enum value for the corresponding key in search_attributes, or None if the entry does not exist or it is not a valid enum value.
Sourcepub fn insert_search_attributes(
&mut self,
key: String,
value: SearchAttributeType,
) -> Option<SearchAttributeType>
pub fn insert_search_attributes( &mut self, key: String, value: SearchAttributeType, ) -> Option<SearchAttributeType>
Inserts a key value pair into search_attributes.