pub struct ContinueAsNewWorkflowExecutionCommandAttributes {Show 16 fields
pub workflow_type: Option<WorkflowType>,
pub task_queue: Option<TaskQueue>,
pub input: Option<Payloads>,
pub workflow_run_timeout: Option<Duration>,
pub workflow_task_timeout: Option<Duration>,
pub backoff_start_interval: Option<Duration>,
pub retry_policy: Option<RetryPolicy>,
pub initiator: i32,
pub failure: Option<Failure>,
pub last_completion_result: Option<Payloads>,
pub cron_schedule: String,
pub header: Option<Header>,
pub memo: Option<Memo>,
pub search_attributes: Option<SearchAttributes>,
pub inherit_build_id: bool,
pub initial_versioning_behavior: i32,
}Fields
workflow_type: Option<WorkflowType>task_queue: Option<TaskQueue>input: Option<Payloads>workflow_run_timeout: Option<Duration>Timeout of a single workflow run.
workflow_task_timeout: Option<Duration>Timeout of a single workflow task.
backoff_start_interval: Option<Duration>How long the workflow start will be delayed - not really a “backoff” in the traditional sense.
retry_policy: Option<RetryPolicy>initiator: i32Should be removed
failure: Option<Failure>Should be removed
last_completion_result: Option<Payloads>Should be removed
cron_schedule: StringShould be removed. Not necessarily unused but unclear and not exposed by SDKs.
header: Option<Header>memo: Option<Memo>search_attributes: Option<SearchAttributes>inherit_build_id: boolIf this is set, the new execution inherits the Build ID of the current execution. Otherwise, the assignment rules will be used to independently assign a Build ID to the new execution. Deprecated. Only considered for versioning v0.2.
initial_versioning_behavior: i32Experimental. Optionally decide the versioning behavior that the first task of the new run should use. For example, choose to AutoUpgrade on continue-as-new instead of inheriting the pinned version of the previous run.
Implementations
Sourceimpl ContinueAsNewWorkflowExecutionCommandAttributes
impl ContinueAsNewWorkflowExecutionCommandAttributes
Sourcepub fn initiator(&self) -> ContinueAsNewInitiator
pub fn initiator(&self) -> ContinueAsNewInitiator
Returns the enum value of initiator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_initiator(&mut self, value: ContinueAsNewInitiator)
pub fn set_initiator(&mut self, value: ContinueAsNewInitiator)
Sets initiator to the provided enum value.
Sourcepub fn initial_versioning_behavior(&self) -> ContinueAsNewVersioningBehavior
pub fn initial_versioning_behavior(&self) -> ContinueAsNewVersioningBehavior
Returns the enum value of initial_versioning_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_initial_versioning_behavior(
&mut self,
value: ContinueAsNewVersioningBehavior,
)
pub fn set_initial_versioning_behavior( &mut self, value: ContinueAsNewVersioningBehavior, )
Sets initial_versioning_behavior to the provided enum value.