pub struct ScheduleActivityTaskCommandAttributes {Show 13 fields
pub activity_id: String,
pub activity_type: Option<ActivityType>,
pub task_queue: Option<TaskQueue>,
pub header: Option<Header>,
pub input: Option<Payloads>,
pub schedule_to_close_timeout: Option<Duration>,
pub schedule_to_start_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub retry_policy: Option<RetryPolicy>,
pub request_eager_execution: bool,
pub use_workflow_build_id: bool,
pub priority: Option<Priority>,
}Fields
activity_id: Stringactivity_type: Option<ActivityType>task_queue: Option<TaskQueue>header: Option<Header>input: Option<Payloads>schedule_to_close_timeout: Option<Duration>Indicates how long the caller is willing to wait for activity completion. The “schedule” time
is when the activity is initially scheduled, not when the most recent retry is scheduled.
Limits how long retries will be attempted. Either this or start_to_close_timeout must be
specified. When not specified, defaults to the workflow execution timeout.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
schedule_to_start_timeout: Option<Duration>Limits the time an activity task can stay in a task queue before a worker picks it up. The
“schedule” time is when the most recent retry is scheduled. This timeout should usually not
be set: it’s useful in specific scenarios like worker-specific task queues. This timeout is
always non retryable, as all a retry would achieve is to put it back into the same queue.
Defaults to schedule_to_close_timeout or workflow execution timeout if that is not
specified. More info:
https://docs.temporal.io/docs/content/what-is-a-schedule-to-start-timeout/
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
start_to_close_timeout: Option<Duration>Maximum time an activity is allowed to execute after being picked up by a worker. This
timeout is always retryable. Either this or schedule_to_close_timeout must be specified.
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
heartbeat_timeout: Option<Duration>Maximum permitted time between successful worker heartbeats.
retry_policy: Option<RetryPolicy>Activities are provided by a default retry policy which is controlled through the service’s
dynamic configuration. Retries will be attempted until schedule_to_close_timeout has
elapsed. To disable retries set retry_policy.maximum_attempts to 1.
request_eager_execution: boolRequest to start the activity directly bypassing matching service and worker polling The slot for executing the activity should be reserved when setting this field to true.
use_workflow_build_id: boolIf this is set, the activity would be assigned to the Build ID of the workflow. Otherwise, Assignment rules of the activity’s Task Queue will be used to determine the Build ID.
priority: Option<Priority>Priority metadata. If this message is not present, or any fields are not present, they inherit the values from the workflow.