pub struct SignalExternalWorkflowExecutionCommandAttributes {
pub namespace: String,
pub execution: Option<WorkflowExecution>,
pub signal_name: String,
pub input: Option<Payloads>,
pub control: String,
pub child_workflow_only: bool,
pub header: Option<Header>,
}Fields
namespace: Stringexecution: Option<WorkflowExecution>signal_name: StringThe workflow author-defined name of the signal to send to the workflow.
input: Option<Payloads>Serialized value(s) to provide with the signal.
control: String👎Deprecated
Deprecated
child_workflow_only: boolSet this to true if the workflow being cancelled is a child of the workflow originating this command. The request will be rejected if it is set to true and the target workflow is not a child of the requesting workflow.
header: Option<Header>Headers that are passed by the workflow that is sending a signal to the external workflow that is receiving this signal.