WorkflowExecution

Struct WorkflowExecution 

pub struct WorkflowExecution {
    pub workflow_id: String,
    pub run_id: String,
}
Identifies a specific workflow within a namespace. Practically speaking, because run_id is a uuid, a workflow execution is globally unique. Note that many commands allow specifying an empty run id as a way of saying “target the latest run of the workflow”.

Fields

workflow_id: Stringrun_id: String