pub struct Message {
pub id: String,
pub protocol_instance_id: String,
pub body: Option<Any>,
pub sequencing_id: Option<SequencingId>,
}Expand description
(– api-linter: core::0146::any=disabled aip.dev/not-precedent: We want runtime extensibility for the body field –)
Fields
id: StringAn ID for this specific message.
protocol_instance_id: StringIdentifies the specific instance of a protocol to which this message belongs.
body: Option<Any>The opaque data carried by this message. The protocol type can be extracted from the package name of the message carried inside the Any.
sequencing_id: Option<SequencingId>The event ID or command ID after which this message can be delivered. The effects of history up to and including this event ID should be visible to the code that handles this message. Omit to opt out of sequencing.