pub struct WorkflowRuleSpec {
pub id: String,
pub visibility_query: String,
pub actions: Vec<WorkflowRuleAction>,
pub expiration_time: Option<Timestamp>,
pub trigger: Option<Trigger>,
}Fields
id: StringThe id of the new workflow rule. Must be unique within the namespace. Can be set by the user, and can have business meaning.
visibility_query: StringRestricted Visibility query. This query is used to filter workflows in this namespace to which this rule should apply. It is applied to any running workflow each time a triggering event occurs, before the trigger predicate is evaluated. The following workflow attributes are supported:
- WorkflowType
- WorkflowId
- StartTime
- ExecutionStatus
actions: Vec<WorkflowRuleAction>WorkflowRuleAction to be taken when the rule is triggered and predicate is matched.
expiration_time: Option<Timestamp>Expiration time of the rule. After this time, the rule will be deleted. Can be empty if the rule should never expire.
trigger: Option<Trigger>Specifies how the rule should be triggered and evaluated. Currently, only “activity start” type is supported.