Modules
- build_
id_ assignment_ rule - Nested message and enum types in
BuildIdAssignmentRule.
Structs
- Build
IdAssignment Rule - Assignment rules are applied to new Workflow and Activity executions at schedule time to assign them to a Build ID.
- Build
IdReachability - Reachability of tasks for a worker by build id, in one or more task queues.
- Compatible
Build IdRedirect Rule - These rules apply to tasks assigned to a particular Build ID
(
source_build_id) to redirect them to another compatible Build ID (target_build_id). - Compatible
Version Set - Used by the worker versioning APIs, represents an unordered set of one or more versions which are considered to be compatible with each other. Currently the versions are always worker build IDs.
- Config
Metadata - Poller
Info - Poller
Scaling Decision - Attached to task responses to give hints to the SDK about how it may adjust its number of pollers.
- Ramp
ByPercentage - Rate
Limit - Rate
Limit Config - Sticky
Execution Attributes - Task
IdBlock - Task
Queue - See https://docs.temporal.io/docs/concepts/task-queues/
- Task
Queue Config - Task
Queue Metadata - Only applies to activity task queues
- Task
Queue Partition Metadata - Task
Queue Reachability - Reachability of tasks for a worker on a single task queue.
- Task
Queue Stats - TaskQueueStats contains statistics about task queue backlog and activity.
- Task
Queue Status - Deprecated. Use
InternalTaskQueueStatus. This is kept untilDescribeTaskQueuesupports legacy behavior. - Task
Queue Type Info - Task
Queue Version Info - Task
Queue Version Selection - Used for specifying versions the caller is interested in.
- Task
Queue Versioning Info - Experimental. Worker Deployments are experimental and might significantly change in the future.
- Timestamped
Build IdAssignment Rule - Timestamped
Compatible Build IdRedirect Rule