pub struct TaskQueueVersioningInfo {
pub current_deployment_version: Option<WorkerDeploymentVersion>,
pub current_version: String,
pub ramping_deployment_version: Option<WorkerDeploymentVersion>,
pub ramping_version: String,
pub ramping_version_percentage: f32,
pub update_time: Option<Timestamp>,
}Expand description
Experimental. Worker Deployments are experimental and might significantly change in the future.
Fields
current_deployment_version: Option<WorkerDeploymentVersion>Specifies which Deployment Version should receive new workflow executions and tasks of
existing unversioned or AutoUpgrade workflows.
Nil value represents all the unversioned workers (those with UNVERSIONED (or unspecified) WorkerVersioningMode.)
Note: Current Version is overridden by the Ramping Version for a portion of traffic when ramp percentage
is non-zero (see ramping_deployment_version and ramping_version_percentage).
current_version: StringDeprecated. Use current_deployment_version.
ramping_deployment_version: Option<WorkerDeploymentVersion>When ramp percentage is non-zero, that portion of traffic is shifted from the Current Version to the Ramping Version.
Must always be different from current_deployment_version unless both are nil.
Nil value represents all the unversioned workers (those with UNVERSIONED (or unspecified) WorkerVersioningMode.)
Note that it is possible to ramp from one Version to another Version, or from unversioned
workers to a particular Version, or from a particular Version to unversioned workers.
ramping_version: StringDeprecated. Use ramping_deployment_version.
ramping_version_percentage: f32Percentage of tasks that are routed to the Ramping Version instead of the Current Version. Valid range: [0, 100]. A 100% value means the Ramping Version is receiving full traffic but not yet “promoted” to be the Current Version, likely due to pending validations. A 0% value means the Ramping Version is receiving no traffic.
update_time: Option<Timestamp>Last time versioning information of this Task Queue changed.