pub struct PendingActivityInfo {Show 24 fields
pub activity_id: String,
pub activity_type: Option<ActivityType>,
pub state: i32,
pub heartbeat_details: Option<Payloads>,
pub last_heartbeat_time: Option<Timestamp>,
pub last_started_time: Option<Timestamp>,
pub attempt: i32,
pub maximum_attempts: i32,
pub scheduled_time: Option<Timestamp>,
pub expiration_time: Option<Timestamp>,
pub last_failure: Option<Failure>,
pub last_worker_identity: String,
pub last_worker_version_stamp: Option<WorkerVersionStamp>,
pub current_retry_interval: Option<Duration>,
pub last_attempt_complete_time: Option<Timestamp>,
pub next_attempt_schedule_time: Option<Timestamp>,
pub paused: bool,
pub last_deployment: Option<Deployment>,
pub last_worker_deployment_version: String,
pub last_deployment_version: Option<WorkerDeploymentVersion>,
pub priority: Option<Priority>,
pub pause_info: Option<PauseInfo>,
pub activity_options: Option<ActivityOptions>,
pub assigned_build_id: Option<AssignedBuildId>,
}Fields
activity_id: Stringactivity_type: Option<ActivityType>state: i32heartbeat_details: Option<Payloads>last_heartbeat_time: Option<Timestamp>last_started_time: Option<Timestamp>attempt: i32maximum_attempts: i32scheduled_time: Option<Timestamp>expiration_time: Option<Timestamp>last_failure: Option<Failure>last_worker_identity: Stringlast_worker_version_stamp: Option<WorkerVersionStamp>Deprecated. The version stamp of the worker to whom this activity was most recently dispatched This field should be cleaned up when versioning-2 API is removed. [cleanup-experimental-wv]
current_retry_interval: Option<Duration>The time activity will wait until the next retry. If activity is currently running it will be next retry interval if activity failed. If activity is currently waiting it will be current retry interval. If there will be no retry it will be null.
last_attempt_complete_time: Option<Timestamp>The time when the last activity attempt was completed. If activity has not been completed yet then it will be null.
next_attempt_schedule_time: Option<Timestamp>Next time when activity will be scheduled. If activity is currently scheduled or started it will be null.
paused: boolIndicates if activity is paused.
last_deployment: Option<Deployment>The deployment this activity was dispatched to most recently. Present only if the activity
was dispatched to a versioned worker.
Deprecated. Use last_deployment_version.
last_worker_deployment_version: StringThe Worker Deployment Version this activity was dispatched to most recently.
Deprecated. Use last_deployment_version.
last_deployment_version: Option<WorkerDeploymentVersion>The Worker Deployment Version this activity was dispatched to most recently. If nil, the activity has not yet been dispatched or was last dispatched to an unversioned worker.
priority: Option<Priority>Priority metadata. If this message is not present, or any fields are not present, they inherit the values from the workflow.
pause_info: Option<PauseInfo>activity_options: Option<ActivityOptions>Current activity options. May be different from the one used to start the activity.
assigned_build_id: Option<AssignedBuildId>Absence of assigned_build_id generally means this task is on an “unversioned” task queue.
In rare cases, it can also mean that the task queue is versioned but we failed to write activity’s
independently-assigned build ID to the database. This case heals automatically once the task is dispatched.
Deprecated. This field should be cleaned up when versioning-2 API is removed. [cleanup-experimental-wv]
Implementations
Sourceimpl PendingActivityInfo
impl PendingActivityInfo
Sourcepub fn state(&self) -> PendingActivityState
pub fn state(&self) -> PendingActivityState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: PendingActivityState)
pub fn set_state(&mut self, value: PendingActivityState)
Sets state to the provided enum value.