pub struct PollActivityTaskQueueResponse {Show 20 fields
pub task_token: Vec<u8>,
pub workflow_namespace: String,
pub workflow_type: Option<WorkflowType>,
pub workflow_execution: Option<WorkflowExecution>,
pub activity_type: Option<ActivityType>,
pub activity_id: String,
pub header: Option<Header>,
pub input: Option<Payloads>,
pub heartbeat_details: Option<Payloads>,
pub scheduled_time: Option<Timestamp>,
pub current_attempt_scheduled_time: Option<Timestamp>,
pub started_time: Option<Timestamp>,
pub attempt: i32,
pub schedule_to_close_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub retry_policy: Option<RetryPolicy>,
pub poller_scaling_decision: Option<PollerScalingDecision>,
pub priority: Option<Priority>,
pub activity_run_id: String,
}Fields
task_token: Vec<u8>A unique identifier for this task
workflow_namespace: StringThe namespace of the activity. If this is a workflow activity then this is the namespace of the workflow also. If this is a standalone activity then the name of this field is misleading, but retained for compatibility with workflow activities.
workflow_type: Option<WorkflowType>Type of the requesting workflow (if this is a workflow activity).
workflow_execution: Option<WorkflowExecution>Execution info of the requesting workflow (if this is a workflow activity)
activity_type: Option<ActivityType>activity_id: StringThe autogenerated or user specified identifier of this activity. Can be used to complete the
activity via RespondActivityTaskCompletedById. May be re-used as long as the last usage
has resolved, but unique IDs for every activity invocation is a good idea.
Note that only a workflow activity ID may be autogenerated.
header: Option<Header>Headers specified by the scheduling workflow. Commonly used to propagate contextual info from the workflow to its activities. For example, tracing contexts.
input: Option<Payloads>Arguments to the activity invocation
heartbeat_details: Option<Payloads>Details of the last heartbeat that was recorded for this activity as of the time this task was delivered.
scheduled_time: Option<Timestamp>When was this task first scheduled
current_attempt_scheduled_time: Option<Timestamp>When was this task attempt scheduled
started_time: Option<Timestamp>When was this task started (this attempt)
attempt: i32Starting at 1, the number of attempts to perform this activity
schedule_to_close_timeout: Option<Duration>First scheduled -> final result reported timeout
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
start_to_close_timeout: Option<Duration>Current attempt start -> final result reported timeout
(– api-linter: core::0140::prepositions=disabled aip.dev/not-precedent: “to” is used to indicate interval. –)
heartbeat_timeout: Option<Duration>Window within which the activity must report a heartbeat, or be timed out.
retry_policy: Option<RetryPolicy>This is the retry policy the service uses which may be different from the one provided (or not) during activity scheduling. The service can override the provided one if some values are not specified or exceed configured system limits.
poller_scaling_decision: Option<PollerScalingDecision>Server-advised information the SDK may use to adjust its poller count.
priority: Option<Priority>Priority metadata
activity_run_id: StringThe run ID of the activity execution, only set for standalone activities.
Implementations
Sourceimpl PollActivityTaskQueueResponse
impl PollActivityTaskQueueResponse
Sourcepub fn sched_to_start(&self) -> Option<Duration>
pub fn sched_to_start(&self) -> Option<Duration>
Return the duration of the task schedule time (current attempt) to its start time if both are set and time went forward.