pub struct RegisterNamespaceRequest {Show 13 fields
pub namespace: String,
pub description: String,
pub owner_email: String,
pub workflow_execution_retention_period: Option<Duration>,
pub clusters: Vec<ClusterReplicationConfig>,
pub active_cluster_name: String,
pub data: HashMap<String, String>,
pub security_token: String,
pub is_global_namespace: bool,
pub history_archival_state: i32,
pub history_archival_uri: String,
pub visibility_archival_state: i32,
pub visibility_archival_uri: String,
}Fields
namespace: Stringdescription: Stringowner_email: Stringworkflow_execution_retention_period: Option<Duration>clusters: Vec<ClusterReplicationConfig>active_cluster_name: Stringdata: HashMap<String, String>A key-value map for any customized purpose.
security_token: Stringis_global_namespace: boolhistory_archival_state: i32If unspecified (ARCHIVAL_STATE_UNSPECIFIED) then default server configuration is used.
history_archival_uri: Stringvisibility_archival_state: i32If unspecified (ARCHIVAL_STATE_UNSPECIFIED) then default server configuration is used.
visibility_archival_uri: StringImplementations
Sourceimpl RegisterNamespaceRequest
impl RegisterNamespaceRequest
Sourcepub fn history_archival_state(&self) -> ArchivalState
pub fn history_archival_state(&self) -> ArchivalState
Returns the enum value of history_archival_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_history_archival_state(&mut self, value: ArchivalState)
pub fn set_history_archival_state(&mut self, value: ArchivalState)
Sets history_archival_state to the provided enum value.
Sourcepub fn visibility_archival_state(&self) -> ArchivalState
pub fn visibility_archival_state(&self) -> ArchivalState
Returns the enum value of visibility_archival_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_visibility_archival_state(&mut self, value: ArchivalState)
pub fn set_visibility_archival_state(&mut self, value: ArchivalState)
Sets visibility_archival_state to the provided enum value.