RespondActivityTaskCompletedRequest

Struct RespondActivityTaskCompletedRequest 

pub struct RespondActivityTaskCompletedRequest {
    pub task_token: Vec<u8>,
    pub result: Option<Payloads>,
    pub identity: String,
    pub namespace: String,
    pub worker_version: Option<WorkerVersionStamp>,
    pub deployment: Option<Deployment>,
    pub deployment_options: Option<WorkerDeploymentOptions>,
}

Fields

task_token: Vec<u8>

The task token as received in PollActivityTaskQueueResponse

result: Option<Payloads>

The result of successfully executing the activity

identity: String

The identity of the worker/client

namespace: Stringworker_version: Option<WorkerVersionStamp>
👎Deprecated

Version info of the worker who processed this task. This message’s build_id field should always be set by SDKs. Workers opting into versioning will also set the use_versioning field to true. See message docstrings for more. Deprecated. Use deployment_options instead.

deployment: Option<Deployment>
👎Deprecated

Deployment info of the worker that completed this task. Must be present if user has set WorkerDeploymentOptions regardless of versioning being enabled or not. Deprecated. Replaced with deployment_options.

deployment_options: Option<WorkerDeploymentOptions>

Worker deployment options that user has set in the worker.