RespondQueryTaskCompletedRequest

Struct RespondQueryTaskCompletedRequest 

pub struct RespondQueryTaskCompletedRequest {
    pub task_token: Vec<u8>,
    pub completed_type: i32,
    pub query_result: Option<Payloads>,
    pub error_message: String,
    pub namespace: String,
    pub failure: Option<Failure>,
    pub cause: i32,
}

Fields

task_token: Vec<u8>completed_type: i32query_result: Option<Payloads>

The result of the query. Mutually exclusive with error_message and failure. Set when the query succeeds.

error_message: String

A plain error message that must be set if completed_type is QUERY_RESULT_TYPE_FAILED. SDKs should also fill in the more complete failure field to provide the full context and support encryption of failure information. error_message will be duplicated if the failure field is present to support callers that pre-date the addition of that field, regardless of whether or not a custom failure converter is used. Mutually exclusive with query_result. Set when the query fails.

namespace: Stringfailure: Option<Failure>

The full reason for this query failure. This field is newer than error_message and can be encoded by the SDK’s failure converter to support E2E encryption of messages and stack traces. Mutually exclusive with query_result. Set when the query fails.

cause: i32

Why did the task fail? It’s important to note that many of the variants in this enum cannot apply to worker responses. See the type’s doc for more.

Implementations

Source

impl RespondQueryTaskCompletedRequest

pub fn completed_type(&self) -> QueryResultType

Returns the enum value of completed_type, or the default if the field is set to an invalid enum value.

pub fn set_completed_type(&mut self, value: QueryResultType)

Sets completed_type to the provided enum value.

pub fn cause(&self) -> WorkflowTaskFailedCause

Returns the enum value of cause, or the default if the field is set to an invalid enum value.

pub fn set_cause(&mut self, value: WorkflowTaskFailedCause)

Sets cause to the provided enum value.