pub fn normalize_http_headers(
headers: HashMap<String, String>,
) -> HashMap<String, String>Expand description
Given a header map, lowercase all the keys and return it as a new map. Any keys that are duplicated after lowercasing will clobber each other in undefined ordering.