pub trait WorkflowDefinition {
type Input: TemporalDeserializable + TemporalSerializable + 'static;
type Output: TemporalDeserializable + TemporalSerializable + 'static;
// Required method
fn name(&self) -> &str;
}Expand description
Implement on a marker struct to define a workflow.
Typically, you will want to use the #[workflow] and #[workflow_methods] macros to define
workflows. However, this trait may be implemented manually if desired.
Required Associated Types
Sourcetype Input: TemporalDeserializable + TemporalSerializable + 'static
type Input: TemporalDeserializable + TemporalSerializable + 'static
Type of the input argument to the workflow
Sourcetype Output: TemporalDeserializable + TemporalSerializable + 'static
type Output: TemporalDeserializable + TemporalSerializable + 'static
Type of the output of the workflow