Contains types that are needed by both the client and the sdk when configuring / interacting with workers.
Structs
- Worker
Deployment Options - Configuration for worker deployment versioning.
- Worker
Deployment Version - Identifies a specific version of a worker deployment.
- Worker
Task Types - Specifies which task types a worker will poll for.
Functions
- build_
id_ from_ current_ exe - Build ID derived from hashing the on-disk bytes of the current executable. Deterministic across machines for the same binary. Cached per-process.